@@ -2,7 +2,7 @@ import re
 import time
 from collections import OrderedDict
 from enum import Enum, unique
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Optional, Union
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
@@ -74,13 +74,13 @@ class ApplicationAutoscalingBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str) -> None:
         super().__init__(region_name, account_id)
         self.ecs_backend = ecs_backends[account_id][region_name]
-        self.targets: Dict[str, Dict[str, FakeScalableTarget]] = OrderedDict()
-        self.policies: Dict[str, FakeApplicationAutoscalingPolicy] = {}
-        self.scheduled_actions: List[FakeScheduledAction] = list()
+        self.targets: dict[str, dict[str, FakeScalableTarget]] = OrderedDict()
+        self.policies: dict[str, FakeApplicationAutoscalingPolicy] = {}
+        self.scheduled_actions: list[FakeScheduledAction] = []
 
     def describe_scalable_targets(
-        self, namespace: str, r_ids: Union[None, List[str]], dimension: Union[None, str]
-    ) -> List["FakeScalableTarget"]:
+        self, namespace: str, r_ids: Union[None, list[str]], dimension: Union[None, str]
+    ) -> list["FakeScalableTarget"]:
         if r_ids is None:
             r_ids = []
         targets = self._flatten_scalable_targets(namespace)
@@ -90,7 +90,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
             targets = [t for t in targets if t.resource_id in r_ids]
         return targets
 
-    def _flatten_scalable_targets(self, namespace: str) -> List["FakeScalableTarget"]:
+    def _flatten_scalable_targets(self, namespace: str) -> list["FakeScalableTarget"]:
         """Flatten scalable targets for a given service namespace down to a list."""
         targets = []
         for dimension in self.targets.keys():
@@ -167,7 +167,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         service_namespace: str,
         resource_id: str,
         scalable_dimension: str,
-        policy_body: Dict[str, Any],
+        policy_body: dict[str, Any],
         policy_type: Optional[None],
     ) -> "FakeApplicationAutoscalingPolicy":
         policy_key = FakeApplicationAutoscalingPolicy.formulate_key(
@@ -206,7 +206,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         scalable_dimension: str,
         max_results: Optional[int],
         next_token: str,
-    ) -> Tuple[Optional[str], List["FakeApplicationAutoscalingPolicy"]]:
+    ) -> tuple[Optional[str], list["FakeApplicationAutoscalingPolicy"]]:
         max_results = max_results or 100
         policies = [
             policy
@@ -272,7 +272,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         service_namespace: str,
         resource_id: str,
         scalable_dimension: str,
-    ) -> List["FakeScheduledAction"]:
+    ) -> list["FakeScheduledAction"]:
         """
         Pagination is not yet implemented
         """
@@ -444,7 +444,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
         resource_id: str,
         scalable_dimension: str,
         policy_type: Optional[str],
-        policy_body: Dict[str, Any],
+        policy_body: dict[str, Any],
     ) -> None:
         self.step_scaling_policy_configuration = None
         self.target_tracking_scaling_policy_configuration = None
@@ -469,7 +469,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
         self._guid = mock_random.uuid4()
         self.policy_arn = f"arn:{get_partition(region_name)}:autoscaling:{region_name}:{account_id}:scalingPolicy:{self._guid}:resource/{self.service_namespace}/{self.resource_id}:policyName/{self.policy_name}"
         self.creation_time = time.time()
-        self.alarms: List["Alarm"] = []
+        self.alarms: list[Alarm] = []
 
         self.account_id = account_id
         self.region_name = region_name
@@ -483,7 +483,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             if self.service_namespace == "ecs":
                 self.alarms.extend(self._generate_ecs_alarms())
 
-    def _generate_dynamodb_alarms(self) -> List["Alarm"]:
+    def _generate_dynamodb_alarms(self) -> list["Alarm"]:
         from moto.cloudwatch.models import CloudWatchBackend, cloudwatch_backends
 
         cloudwatch: CloudWatchBackend = cloudwatch_backends[self.account_id][
@@ -554,13 +554,13 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
         alarms.append(alarm4)
         return alarms
 
-    def _generate_ecs_alarms(self) -> List["Alarm"]:
+    def _generate_ecs_alarms(self) -> list["Alarm"]:
         from moto.cloudwatch.models import CloudWatchBackend, cloudwatch_backends
 
         cloudwatch: CloudWatchBackend = cloudwatch_backends[self.account_id][
             self.region_name
         ]
-        alarms: List["Alarm"] = []
+        alarms: list[Alarm] = []
         alarm_action = f"{self.policy_arn}:createdBy/{mock_random.uuid4()}"
         config = self.target_tracking_scaling_policy_configuration or {}
         metric_spec = config.get("PredefinedMetricSpecification", {})
