@@ -1,6 +1,8 @@
 import copy
+import math
 from collections import defaultdict
-from typing import Any, Dict, List, Optional, Sequence, Tuple
+from collections.abc import Sequence
+from typing import Any, Optional, Union
 
 from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.core.utils import unix_time, unix_time_millis, utcnow
@@ -14,22 +16,26 @@ from moto.dynamodb.exceptions import (
     MockValidationException,
     RangeKeyTooLong,
     SerializationException,
+    ValidationException,
 )
 from moto.dynamodb.limits import HASH_KEY_MAX_LENGTH, RANGE_KEY_MAX_LENGTH
 from moto.dynamodb.models.dynamo_type import DynamoType, Item
 from moto.dynamodb.models.utilities import dynamo_json_dump
 from moto.moto_api._internal import mock_random
+from moto.utilities.utils import get_partition
 
 RESULT_SIZE_LIMIT = 1000000  # DynamoDB has a 1MB size limit
+DEFAULT_WARM_THROUGHPUT_RCU = 12000
+DEFAULT_WARM_THROUGHPUT_WCU = 4000
 
 
 class SecondaryIndex(BaseModel):
     def __init__(
         self,
         index_name: str,
-        schema: List[Dict[str, str]],
-        projection: Dict[str, Any],
-        table_key_attrs: List[str],
+        schema: list[dict[str, str]],
+        projection: dict[str, Any],
+        table_key_attrs: list[str],
     ):
         self.name = index_name
         self.schema = schema
@@ -68,7 +74,7 @@ class SecondaryIndex(BaseModel):
 
 
 class LocalSecondaryIndex(SecondaryIndex):
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "IndexName": self.name,
             "KeySchema": self.schema,
@@ -77,7 +83,7 @@ class LocalSecondaryIndex(SecondaryIndex):
 
     @staticmethod
     def create(  # type: ignore[misc]
-        dct: Dict[str, Any], table_key_attrs: List[str]
+        dct: dict[str, Any], table_key_attrs: list[str]
     ) -> "LocalSecondaryIndex":
         return LocalSecondaryIndex(
             index_name=dct["IndexName"],
@@ -91,31 +97,45 @@ class GlobalSecondaryIndex(SecondaryIndex):
     def __init__(
         self,
         index_name: str,
-        schema: List[Dict[str, str]],
-        projection: Dict[str, Any],
-        table_key_attrs: List[str],
+        schema: list[dict[str, str]],
+        projection: dict[str, Any],
+        table_key_attrs: list[str],
         status: str = "ACTIVE",
-        throughput: Optional[Dict[str, Any]] = None,
+        throughput: Optional[dict[str, Any]] = None,
+        warm_throughput: Optional[dict[str, Any]] = None,
     ):
         super().__init__(index_name, schema, projection, table_key_attrs)
         self.status = status
-        self.throughput = throughput or {
-            "ReadCapacityUnits": 0,
-            "WriteCapacityUnits": 0,
-        }
+        if throughput:
+            self.throughput = throughput
+            self.warm_throughput = warm_throughput or {
+                "ReadUnitsPerSecond": throughput["ReadCapacityUnits"],
+                "WriteUnitsPerSecond": throughput["WriteCapacityUnits"],
+            }
+        else:
+            self.throughput = {
+                "ReadCapacityUnits": 0,
+                "WriteCapacityUnits": 0,
+            }
+            self.warm_throughput = warm_throughput or {
+                "ReadUnitsPerSecond": DEFAULT_WARM_THROUGHPUT_RCU,
+                "WriteUnitsPerSecond": DEFAULT_WARM_THROUGHPUT_WCU,
+            }
+        self.warm_throughput["Status"] = "ACTIVE"
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "IndexName": self.name,
             "KeySchema": self.schema,
             "Projection": self.projection,
             "IndexStatus": self.status,
             "ProvisionedThroughput": self.throughput,
+            "WarmThroughput": self.warm_throughput,
         }
 
     @staticmethod
     def create(  # type: ignore[misc]
-        dct: Dict[str, Any], table_key_attrs: List[str]
+        dct: dict[str, Any], table_key_attrs: list[str]
     ) -> "GlobalSecondaryIndex":
         return GlobalSecondaryIndex(
             index_name=dct["IndexName"],
@@ -123,13 +143,16 @@ class GlobalSecondaryIndex(SecondaryIndex):
             projection=dct["Projection"],
             table_key_attrs=table_key_attrs,
             throughput=dct.get("ProvisionedThroughput", None),
+            warm_throughput=dct.get("WarmThroughput", None),
         )
 
-    def update(self, u: Dict[str, Any]) -> None:
+    def update(self, u: dict[str, Any]) -> None:
         self.name = u.get("IndexName", self.name)
         self.schema = u.get("KeySchema", self.schema)
         self.projection = u.get("Projection", self.projection)
         self.throughput = u.get("ProvisionedThroughput", self.throughput)
+        self.warm_throughput = u.get("WarmThroughput", self.warm_throughput)
+        self.warm_throughput["Status"] = "ACTIVE"
 
 
 class StreamRecord(BaseModel):
@@ -150,7 +173,7 @@ class StreamRecord(BaseModel):
         if table.range_key_attr is not None and rec is not None:
             keys[table.range_key_attr] = rec.range_key.to_json()  # type: ignore
 
-        self.record: Dict[str, Any] = {
+        self.record: dict[str, Any] = {
             "eventID": mock_random.uuid4().hex,
             "eventName": event_name,
             "eventSource": "aws:dynamodb",
@@ -175,7 +198,7 @@ class StreamRecord(BaseModel):
             dynamo_json_dump(self.record["dynamodb"])
         )
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return self.record
 
 
@@ -185,10 +208,10 @@ class StreamShard(BaseModel):
         self.table = table
         self.id = "shardId-00000001541626099285-f35f62ef"
         self.starting_sequence_number = 1100000000017454423009
-        self.items: List[StreamRecord] = []
+        self.items: list[StreamRecord] = []
         self.created_on = utcnow()
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "ShardId": self.id,
             "SequenceNumberRange": {
@@ -210,9 +233,7 @@ class StreamShard(BaseModel):
         from moto.awslambda.utils import get_backend
 
         for arn, esm in self.table.lambda_event_source_mappings.items():
-            region = arn[
-                len("arn:aws:lambda:") : arn.index(":", len("arn:aws:lambda:"))
-            ]
+            region = arn.split(":")[3]
 
             result = get_backend(self.account_id, region).send_dynamodb_items(
                 arn, self.items, esm.event_source_arn
@@ -221,7 +242,7 @@ class StreamShard(BaseModel):
         if result:
             self.items = []
 
-    def get(self, start: int, quantity: int) -> List[Dict[str, Any]]:
+    def get(self, start: int, quantity: int) -> list[dict[str, Any]]:
         start -= self.starting_sequence_number
         assert start >= 0
         end = start + quantity
@@ -234,15 +255,17 @@ class Table(CloudFormationModel):
         table_name: str,
         account_id: str,
         region: str,
-        schema: List[Dict[str, Any]],
-        attr: List[Dict[str, str]],
-        throughput: Optional[Dict[str, int]] = None,
+        schema: list[dict[str, Any]],
+        attr: list[dict[str, str]],
+        throughput: Optional[dict[str, int]] = None,
         billing_mode: Optional[str] = None,
-        indexes: Optional[List[Dict[str, Any]]] = None,
-        global_indexes: Optional[List[Dict[str, Any]]] = None,
-        streams: Optional[Dict[str, Any]] = None,
-        sse_specification: Optional[Dict[str, Any]] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        indexes: Optional[list[dict[str, Any]]] = None,
+        global_indexes: Optional[list[dict[str, Any]]] = None,
+        streams: Optional[dict[str, Any]] = None,
+        sse_specification: Optional[dict[str, Any]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
+        deletion_protection_enabled: Optional[bool] = False,
+        warm_throughput: Optional[dict[str, Any]] = None,
     ):
         self.name = table_name
         self.account_id = account_id
@@ -269,11 +292,23 @@ class Table(CloudFormationModel):
             key for key in (self.hash_key_attr, self.range_key_attr) if key is not None
         ]
         self.billing_mode = billing_mode
-        if throughput is None:
-            self.throughput = {"WriteCapacityUnits": 0, "ReadCapacityUnits": 0}
-        else:
+        if throughput:
             self.throughput = throughput
+            self.warm_throughput = warm_throughput or {
+                "ReadUnitsPerSecond": throughput["ReadCapacityUnits"],
+                "WriteUnitsPerSecond": throughput["WriteCapacityUnits"],
+            }
+        else:
+            self.throughput = {
+                "ReadCapacityUnits": 0,
+                "WriteCapacityUnits": 0,
+            }
+            self.warm_throughput = warm_throughput or {
+                "ReadUnitsPerSecond": DEFAULT_WARM_THROUGHPUT_RCU,
+                "WriteUnitsPerSecond": DEFAULT_WARM_THROUGHPUT_WCU,
+            }
         self.throughput["NumberOfDecreasesToday"] = 0
+        self.warm_throughput["Status"] = "ACTIVE"
         self.indexes = [
             LocalSecondaryIndex.create(i, self.table_key_attrs)
             for i in (indexes if indexes else [])
@@ -290,12 +325,12 @@ class Table(CloudFormationModel):
             "TimeToLiveStatus": "DISABLED"  # One of 'ENABLING'|'DISABLING'|'ENABLED'|'DISABLED',
             # 'AttributeName': 'string'  # Can contain this
         }
-        self.stream_specification: Optional[Dict[str, Any]] = {"StreamEnabled": False}
+        self.stream_specification: Optional[dict[str, Any]] = {"StreamEnabled": False}
         self.latest_stream_label: Optional[str] = None
         self.stream_shard: Optional[StreamShard] = None
         self.set_stream_specification(streams)
-        self.lambda_event_source_mappings: Dict[str, Any] = {}
-        self.continuous_backups: Dict[str, Any] = {
+        self.lambda_event_source_mappings: dict[str, Any] = {}
+        self.continuous_backups: dict[str, Any] = {
             "ContinuousBackupsStatus": "ENABLED",  # One of 'ENABLED'|'DISABLED', it's enabled by default
             "PointInTimeRecoveryDescription": {
                 "PointInTimeRecoveryStatus": "DISABLED"  # One of 'ENABLED'|'DISABLED'
@@ -306,6 +341,7 @@ class Table(CloudFormationModel):
             self.sse_specification["KMSMasterKeyId"] = self._get_default_encryption_key(
                 account_id, region
             )
+        self.deletion_protection_enabled = deletion_protection_enabled
 
     def _get_default_encryption_key(self, account_id: str, region: str) -> str:
         from moto.kms import kms_backends
@@ -323,7 +359,7 @@ class Table(CloudFormationModel):
                 description="Default master key that protects my DynamoDB table storage",
                 tags=None,
             )
-            kms.add_alias(key.id, ddb_alias)
+            kms.create_alias(key.id, ddb_alias)
         ebs_key = kms.describe_key(ddb_alias)
         return ebs_key.arn
 
@@ -346,9 +382,9 @@ class Table(CloudFormationModel):
         return self.name
 
     @property
-    def attribute_keys(self) -> List[str]:
+    def attribute_keys(self) -> list[str]:
         # A set of all the hash or range attributes for all indexes
-        def keys_from_index(idx: SecondaryIndex) -> List[str]:
+        def keys_from_index(idx: SecondaryIndex) -> list[str]:
             schema = idx.schema
             return [attr["AttributeName"] for attr in schema]
 
@@ -370,7 +406,7 @@ class Table(CloudFormationModel):
     def create_from_cloudformation_json(  # type: ignore[misc]
         cls,
         resource_name: str,
-        cloudformation_json: Dict[str, Any],
+        cloudformation_json: dict[str, Any],
         account_id: str,
         region_name: str,
         **kwargs: Any,
@@ -384,14 +420,23 @@ class Table(CloudFormationModel):
             params["schema"] = properties["KeySchema"]
         if "AttributeDefinitions" in properties:
             params["attr"] = properties["AttributeDefinitions"]
-        if "GlobalSecondaryIndexes" in properties:
-            params["global_indexes"] = properties["GlobalSecondaryIndexes"]
-        if "ProvisionedThroughput" in properties:
-            params["throughput"] = properties["ProvisionedThroughput"]
-        if "LocalSecondaryIndexes" in properties:
-            params["indexes"] = properties["LocalSecondaryIndexes"]
-        if "StreamSpecification" in properties:
-            params["streams"] = properties["StreamSpecification"]
+        params["global_indexes"] = properties.get("GlobalSecondaryIndexes", [])
+        params["throughput"] = properties.get("ProvisionedThroughput")
+        params["indexes"] = properties.get("LocalSecondaryIndexes", [])
+        params["streams"] = properties.get("StreamSpecification")
+        params["tags"] = properties.get("Tags")
+        params["deletion_protection_enabled"] = properties.get(
+            "DeletionProtectionEnabled", False
+        )
+        params["sse_specification"] = properties.get("SSESpecification")
+        params["warm_throughput"] = properties.get("WarmThroughput")
+
+        billing_mode = (
+            "PAY_PER_REQUEST"
+            if properties.get("BillingMode") == "PAY_PER_REQUEST"
+            else "PROVISIONED"
+        )
+        params["billing_mode"] = billing_mode
 
         table = dynamodb_backends[account_id][region_name].create_table(
             name=resource_name, **params
@@ -402,7 +447,7 @@ class Table(CloudFormationModel):
     def delete_from_cloudformation_json(  # type: ignore[misc]
         cls,
         resource_name: str,
-        cloudformation_json: Dict[str, Any],
+        cloudformation_json: dict[str, Any],
         account_id: str,
         region_name: str,
     ) -> None:
@@ -411,9 +456,9 @@ class Table(CloudFormationModel):
         dynamodb_backends[account_id][region_name].delete_table(name=resource_name)
 
     def _generate_arn(self, name: str) -> str:
-        return f"arn:aws:dynamodb:{self.region_name}:{self.account_id}:table/{name}"
+        return f"arn:{get_partition(self.region_name)}:dynamodb:{self.region_name}:{self.account_id}:table/{name}"
 
-    def set_stream_specification(self, streams: Optional[Dict[str, Any]]) -> None:
+    def set_stream_specification(self, streams: Optional[dict[str, Any]]) -> None:
         self.stream_specification = streams
         if (
             self.stream_specification
@@ -426,8 +471,8 @@ class Table(CloudFormationModel):
         else:
             self.stream_specification = {"StreamEnabled": False}
 
-    def describe(self, base_key: str = "TableDescription") -> Dict[str, Any]:
-        results: Dict[str, Any] = {
+    def describe(self, base_key: str = "TableDescription") -> dict[str, Any]:
+        results: dict[str, Any] = {
             base_key: {
                 "AttributeDefinitions": self.attr,
                 "ProvisionedThroughput": self.throughput,
@@ -443,6 +488,8 @@ class Table(CloudFormationModel):
                     index.describe() for index in self.global_indexes
                 ],
                 "LocalSecondaryIndexes": [index.describe() for index in self.indexes],
+                "DeletionProtectionEnabled": self.deletion_protection_enabled,
+                "WarmThroughput": self.warm_throughput,
             }
         }
         if self.latest_stream_label:
@@ -466,7 +513,7 @@ class Table(CloudFormationModel):
         )
 
     @property
-    def hash_key_names(self) -> List[str]:
+    def hash_key_names(self) -> list[str]:
         keys = [self.hash_key_attr]
         for index in self.global_indexes:
             for key in index.schema:
@@ -475,7 +522,7 @@ class Table(CloudFormationModel):
         return keys
 
     @property
-    def range_key_names(self) -> List[str]:
+    def range_key_names(self) -> list[str]:
         keys = [self.range_key_attr] if self.has_range_key else []
         for index in self.global_indexes:
             for key in index.schema:
@@ -483,7 +530,7 @@ class Table(CloudFormationModel):
                     keys.append(key["AttributeName"])
         return keys  # type: ignore[return-value]
 
-    def _validate_key_sizes(self, item_attrs: Dict[str, Any]) -> None:
+    def _validate_key_sizes(self, item_attrs: dict[str, Any]) -> None:
         for hash_name in self.hash_key_names:
             hash_value = item_attrs.get(hash_name)
             if hash_value:
@@ -496,14 +543,14 @@ class Table(CloudFormationModel):
                     raise RangeKeyTooLong
 
     def _validate_item_types(
-        self, item_attrs: Dict[str, Any], attr: Optional[str] = None
+        self, item_attrs: dict[str, Any], attr: Optional[str] = None
     ) -> None:
         for key, value in item_attrs.items():
             if isinstance(value, dict):
                 self._validate_item_types(value, attr=key if attr is None else key)
-            elif isinstance(value, int) and key == "N":
-                raise InvalidConversion
-            if key == "S":
+            if key == "N":
+                self._validate_number_type(value)
+            elif key == "S":
                 # This scenario is usually caught by boto3, but the user can disable parameter validation
                 # Which is why we need to catch it 'server-side' as well
                 if isinstance(value, int):
@@ -514,14 +561,66 @@ class Table(CloudFormationModel):
                     raise SerializationException(
                         "Start of structure or map found where not expected"
                     )
+            elif key == "NULL":
+                if isinstance(value, bool):
+                    if value is not True:
+                        raise ValidationException(
+                            "Null attribute value types must have the value of true"
+                        )
+                # Non-bool values are raise elsewhere as a ParamValidationError
+
+    def _validate_number_type(self, value: Any) -> None:
+        if isinstance(value, int):
+            # TODO int and float values actually raise a ParamValidationError
+            raise InvalidConversion
+        if isinstance(value, float):
+            raise InvalidConversion
+        if not isinstance(value, str):
+            # TODO This is probably bad too, but keep current behavior
+            return
+
+        non_numeric_error = (
+            f"The parameter cannot be converted to a numeric value: {value}"
+        )
+
+        # Quick check - if the value can't be converted to a Python float, consider it invalid
+        try:
+            float_val = float(value)
+        except ValueError:
+            raise ValidationException(non_numeric_error)
+
+        # Check for leading/trailing whitespace
+        if value != value.strip():
+            raise ValidationException(non_numeric_error)
+
+        if not math.isfinite(float_val):
+            raise ValidationException(non_numeric_error)
+
+        # More detailed range checks based on these rules:
+        # * Numbers can be positive, negative, or zero. Numbers can have up to 38 digits of precision. Exceeding this results in an exception.
+        # * Positive range: 1E-130 to 9.9999999999999999999999999999999999999E+125
+        # * Negative range: -9.9999999999999999999999999999999999999E+125 to -1E-130
+        # In DynamoDB, numbers are represented as variable length. Leading and trailing zeroes are trimmed.
+        # Source: https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.NamingRulesDataTypes.html
+        if float_val != 0.0:
+            if abs(float_val) > 9.9999999999999999999999999999999999999e125:
+                raise ValidationException(
+                    "Number overflow. Attempting to store a number with magnitude larger than supported range"
+                )
+            elif abs(float_val) < 1e-130:
+                raise ValidationException(
+                    "Number underflow. Attempting to store a number with magnitude smaller than supported range"
+                )
+
+        return
 
     def put_item(
         self,
-        item_attrs: Dict[str, Any],
-        expected: Optional[Dict[str, Any]] = None,
+        item_attrs: dict[str, Any],
+        expected: Optional[dict[str, Any]] = None,
         condition_expression: Optional[str] = None,
-        expression_attribute_names: Optional[Dict[str, str]] = None,
-        expression_attribute_values: Optional[Dict[str, Any]] = None,
+        expression_attribute_names: Optional[dict[str, str]] = None,
+        expression_attribute_values: Optional[dict[str, Any]] = None,
         overwrite: bool = False,
         return_values_on_condition_check_failure: Optional[str] = None,
     ) -> Item:
@@ -610,7 +709,7 @@ class Table(CloudFormationModel):
         self,
         hash_key: DynamoType,
         range_key: Optional[DynamoType] = None,
-        projection_expression: Optional[List[List[str]]] = None,
+        projection_expression: Optional[list[list[str]]] = None,
     ) -> Optional[Item]:
         if self.has_range_key and not range_key:
             raise MockValidationException(
@@ -651,20 +750,20 @@ class Table(CloudFormationModel):
         self,
         hash_key: DynamoType,
         range_comparison: Optional[str],
-        range_objs: List[DynamoType],
+        range_objs: list[DynamoType],
         limit: int,
-        exclusive_start_key: Dict[str, Any],
+        exclusive_start_key: dict[str, Any],
         scan_index_forward: bool,
-        projection_expressions: Optional[List[List[str]]],
+        projection_expressions: Optional[list[list[str]]],
         index_name: Optional[str] = None,
         consistent_read: bool = False,
         filter_expression: Any = None,
         **filter_kwargs: Any,
-    ) -> Tuple[List[Item], int, Optional[Dict[str, Any]]]:
+    ) -> tuple[list[Item], int, Optional[dict[str, Any]]]:
         # FIND POSSIBLE RESULTS
         if index_name:
             all_indexes = self.all_indexes()
-            indexes_by_name = dict((i.name, i) for i in all_indexes)
+            indexes_by_name = {i.name: i for i in all_indexes}
             if index_name not in indexes_by_name:
                 all_names = ", ".join(indexes_by_name.keys())
                 raise MockValidationException(
@@ -692,36 +791,41 @@ class Table(CloudFormationModel):
                     key for key in index.schema if key["KeyType"] == "RANGE"
                 ][0]
             except IndexError:
-                if isinstance(index, GlobalSecondaryIndex):
-                    # If we're querying a GSI that does not have an index, the main hash key acts as a range key
-                    index_range_key = {"AttributeName": self.hash_key_attr}
+                if isinstance(index, GlobalSecondaryIndex) and self.range_key_attr:
+                    # If we're querying a GSI that does not have a range key, the main range key acts as a range key
+                    index_range_key = {"AttributeName": self.range_key_attr}
                 else:
-                    index_range_key = None
+                    # If we don't have a range key on the main table either, the hash key acts as a range key
+                    index_range_key = {"AttributeName": self.hash_key_attr}
                 if range_comparison:
                     raise ValueError(
                         f"Range Key comparison but no range key found for index: {index_name}"
                     )
 
-            actual_hash_attr = index_hash_key["AttributeName"]
-            actual_range_attr = (
-                index_range_key["AttributeName"] if index_range_key else None
-            )
+            hash_attrs = [index_hash_key["AttributeName"], self.hash_key_attr]
+            if index_range_key:
+                range_attrs = [
+                    index_range_key["AttributeName"],
+                    self.range_key_attr,
+                ]
+            else:
+                range_attrs = [self.range_key_attr]
 
             possible_results = []
             for item in self.all_items():
                 if not isinstance(item, Item):
                     continue
-                item_hash_key = item.attrs.get(actual_hash_attr)
-                if actual_range_attr is None:
+                item_hash_key = item.attrs.get(hash_attrs[0])
+                if len(range_attrs) == 1:
                     if item_hash_key and item_hash_key == hash_key:
                         possible_results.append(item)
                 else:
-                    item_range_key = item.attrs.get(actual_range_attr)
+                    item_range_key = item.attrs.get(range_attrs[0])  # type: ignore
                     if item_hash_key and item_hash_key == hash_key and item_range_key:
                         possible_results.append(item)
         else:
-            actual_hash_attr = self.hash_key_attr
-            actual_range_attr = self.range_key_attr
+            hash_attrs = [self.hash_key_attr]
+            range_attrs = [self.range_key_attr]
 
             possible_results = [
                 item
@@ -731,18 +835,9 @@ class Table(CloudFormationModel):
 
         # SORT
         if index_name:
-            if actual_range_attr is not None:
-                # Convert to float if necessary to ensure proper ordering
-                def conv(x: DynamoType) -> Any:
-                    return float(x.value) if x.type == "N" else x.value
-
-                possible_results.sort(
-                    key=lambda item: (  # type: ignore
-                        conv(item.attrs[actual_range_attr])  # type: ignore
-                        if item.attrs.get(actual_range_attr)
-                        else None
-                    )
-                )
+            possible_results = self.sorted_items(
+                hash_attrs, range_attrs, possible_results
+            )
         else:
             possible_results.sort(key=lambda item: item.range_key)  # type: ignore
 
@@ -750,7 +845,7 @@ class Table(CloudFormationModel):
             possible_results.reverse()
 
         # FILTER
-        results: List[Item] = []
+        results: list[Item] = []
         result_size = 0
         scanned_count = 0
         last_evaluated_key = None
@@ -762,8 +857,8 @@ class Table(CloudFormationModel):
                 if self._item_comes_before_dct(
                     result,
                     exclusive_start_key,
-                    actual_hash_attr,
-                    actual_range_attr,
+                    hash_attrs,
+                    range_attrs,
                     scan_index_forward,
                 ):
                     continue
@@ -787,7 +882,11 @@ class Table(CloudFormationModel):
                 scanned_count += 1
 
             if range_comparison:
-                if index_name:
+                if (
+                    index_name
+                    and index_range_key
+                    and result.attrs.get(index_range_key["AttributeName"])
+                ):
                     if result.attrs.get(index_range_key["AttributeName"]).compare(  # type: ignore
                         range_comparison, range_objs
                     ):
@@ -825,8 +924,8 @@ class Table(CloudFormationModel):
 
         return results, scanned_count, last_evaluated_key
 
-    def all_items(self) -> List[Item]:
-        items: List[Item] = []
+    def all_items(self) -> list[Item]:
+        items: list[Item] = []
         for hash_set in self.items.values():
             if self.range_key_attr:
                 for item in hash_set.values():
@@ -843,18 +942,18 @@ class Table(CloudFormationModel):
 
     def get_index(self, index_name: str, error_if_not: bool = False) -> SecondaryIndex:
         all_indexes = self.all_indexes()
-        indexes_by_name = dict((i.name, i) for i in all_indexes)
+        indexes_by_name = {i.name: i for i in all_indexes}
         if error_if_not and index_name not in indexes_by_name:
             raise InvalidIndexNameError(
                 f"The table does not have the specified index: {index_name}"
             )
         return indexes_by_name[index_name]
 
-    def has_idx_items(self, index_name: str) -> List[Item]:
+    def has_idx_items(self, index_name: str) -> list[Item]:
         idx = self.get_index(index_name)
-        idx_col_set = set([i["AttributeName"] for i in idx.schema])
+        idx_col_set = {i["AttributeName"] for i in idx.schema}
 
-        items: List[Item] = []
+        items: list[Item] = []
 
         for hash_set in self.items.values():
             if self.range_key_attr:
@@ -864,22 +963,20 @@ class Table(CloudFormationModel):
             else:
                 if idx_col_set.issubset(set(hash_set.attrs)):  # type: ignore
                     items.append(hash_set)  # type: ignore
-        return sorted(
-            items,
-            key=lambda x: (x.hash_key, x.range_key) if x.range_key else x.hash_key,
-        )
+        return items
 
     def scan(
         self,
-        filters: Dict[str, Any],
+        filters: dict[str, Any],
         limit: int,
-        exclusive_start_key: Dict[str, Any],
+        exclusive_start_key: dict[str, Any],
         filter_expression: Any = None,
         index_name: Optional[str] = None,
         consistent_read: bool = False,
-        projection_expression: Optional[List[List[str]]] = None,
-    ) -> Tuple[List[Item], int, Optional[Dict[str, Any]]]:
-        results: List[Item] = []
+        projection_expression: Optional[list[list[str]]] = None,
+        segments: Union[tuple[None, None], tuple[int, int]] = (None, None),
+    ) -> tuple[list[Item], int, Optional[dict[str, Any]]]:
+        results: list[Item] = []
         result_size = 0
         scanned_count = 0
 
@@ -907,29 +1004,34 @@ class Table(CloudFormationModel):
             except IndexError:
                 index_range_key = None
 
-            actual_hash_attr = index_hash_key["AttributeName"]
-            actual_range_attr = (
-                index_range_key["AttributeName"] if index_range_key else None
-            )
+            hash_attrs = [index_hash_key["AttributeName"], self.hash_key_attr]
+            if index_range_key:
+                range_attrs = [index_range_key["AttributeName"], self.range_key_attr]
+            else:
+                range_attrs = [self.range_key_attr]
 
             items = self.has_idx_items(index_name)
+            items = self.sorted_items(hash_attrs, range_attrs, items)
         else:
-            actual_hash_attr = self.hash_key_attr
-            actual_range_attr = self.range_key_attr
+            hash_attrs = [self.hash_key_attr]
+            range_attrs = [self.range_key_attr]
 
             items = self.all_items()
 
         last_evaluated_key = None
         processing_previous_page = exclusive_start_key is not None
         for item in items:
+            if not item.is_within_segment(segments):
+                continue
+
             # Cycle through the previous page of results
             # When we encounter our start key, we know we've reached the end of the previous page
             if processing_previous_page:
                 if self._item_comes_before_dct(
                     item,
                     exclusive_start_key,
-                    actual_hash_attr,
-                    actual_range_attr,
+                    hash_attrs,
+                    range_attrs,
                     True,
                 ):
                     continue
@@ -988,32 +1090,75 @@ class Table(CloudFormationModel):
     def _item_comes_before_dct(
         self,
         item: Item,
-        dct: Dict[str, Any],
-        hash_key_attr: str,
-        range_key_attr: Optional[str],
+        dct: dict[str, Any],
+        hash_key_attrs: list[str],
+        range_key_attrs: list[Optional[str]],
         scan_index_forward: bool,
     ) -> bool:
-        """Does item appear before or at dct relative to sort options?"""
-        dict_hash_val = DynamoType(dct.get(hash_key_attr))  # type: ignore[arg-type]
-        item_hash_val = item.attrs[hash_key_attr]
-        if item_hash_val != dict_hash_val:
-            # If hash keys are different, order immediately
-            return bool(item_hash_val < dict_hash_val) == scan_index_forward
-        if range_key_attr is None:
-            # If hash keys match and no range key, items are identical
-            return True
-        # We know hash keys are equal, use range key as tiebreaker
-        dict_range_val = DynamoType(dct.get(range_key_attr))  # type: ignore[arg-type]
-        item_range_val = item.attrs[range_key_attr]
-        if item_range_val == dict_range_val:
-            # If range keys (also) match, items are identical
-            return True
-        # Range keys are different, order accordingly
-        return bool(item_range_val < dict_range_val) == scan_index_forward  # type: ignore[arg-type]
+        """
+        Does item appear before or at dct relative to sort options?
+
+        hash_key_attrs: The list of hash keys.
+        Includes the key of the GSI (first, if it exists) and the key of the main table.
+
+        range_key_attrs: A list of range keys (RK).
+        Includes the RK-name of the GSI (first, if it exists) and the RK-name of the main table (second - can be None).
+        When sorting a GSI, we'll try to sort by the GSI RK first.
+        However, because GSI RK's are not unique (by design), item and dct can have the same RK-value
+        If that is the case, we compare by the RK of the main table instead
+        Related: https://github.com/getmoto/moto/issues/7761
+        """
+        attrs_to_sort_by = self._generate_attr_to_sort_by(
+            hash_key_attrs, range_key_attrs
+        )
+        for attr in attrs_to_sort_by:
+            if attr in item.attrs and item.attrs[attr] != DynamoType(dct.get(attr)):  # type: ignore
+                return (
+                    (item.attrs[attr] < DynamoType(dct.get(attr)))  # type: ignore
+                    == scan_index_forward
+                )
+        # Keys were equal, items are identical
+        return True
+
+    def sorted_items(
+        self,
+        hash_key_attrs: list[str],
+        range_key_attrs: list[Optional[str]],
+        items: list[Item],
+    ) -> list[Item]:
+        attrs_to_sort_by = self._generate_attr_to_sort_by(
+            hash_key_attrs, range_key_attrs
+        )
+        items.sort(
+            key=lambda x: tuple([x.attrs[key] for key in attrs_to_sort_by]),
+        )
+        return items
+
+    def _generate_attr_to_sort_by(
+        self, hash_key_attrs: list[str], range_key_attrs: list[Optional[str]]
+    ) -> list[str]:
+        gsi_hash_key = hash_key_attrs[0] if len(hash_key_attrs) == 2 else None
+        table_hash_key = str(
+            hash_key_attrs[0] if gsi_hash_key is None else hash_key_attrs[1]
+        )
+        gsi_range_key = range_key_attrs[0] if len(range_key_attrs) == 2 else None
+        table_range_key = str(
+            range_key_attrs[0] if gsi_range_key is None else range_key_attrs[1]
+        )
+        # Gets the GSI and table hash and range keys in the order to try sorting by
+        attrs_to_sort_by = [
+            gsi_hash_key,
+            gsi_range_key,
+            table_hash_key,
+            table_range_key,
+        ]
+        return [
+            attr for attr in attrs_to_sort_by if attr is not None and attr != "None"
+        ]
 
     def _get_last_evaluated_key(
         self, last_result: Item, index_name: Optional[str]
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         last_evaluated_key = {self.hash_key_attr: last_result.hash_key}
         if self.range_key_attr is not None and last_result.range_key is not None:
             last_evaluated_key[self.range_key_attr] = last_result.range_key
@@ -1058,10 +1203,10 @@ class Backup:
 
     @property
     def arn(self) -> str:
-        return f"arn:aws:dynamodb:{self.region_name}:{self.account_id}:table/{self.table.name}/backup/{self.identifier}"
+        return f"arn:{get_partition(self.region_name)}:dynamodb:{self.region_name}:{self.account_id}:table/{self.table.name}/backup/{self.identifier}"
 
     @property
-    def details(self) -> Dict[str, Any]:  # type: ignore[misc]
+    def details(self) -> dict[str, Any]:  # type: ignore[misc]
         return {
             "BackupArn": self.arn,
             "BackupName": self.name,
@@ -1072,7 +1217,7 @@ class Backup:
         }
 
     @property
-    def summary(self) -> Dict[str, Any]:  # type: ignore[misc]
+    def summary(self) -> dict[str, Any]:  # type: ignore[misc]
         return {
             "TableName": self.table.name,
             # 'TableId': 'string',
@@ -1087,7 +1232,7 @@ class Backup:
         }
 
     @property
-    def description(self) -> Dict[str, Any]:  # type: ignore[misc]
+    def description(self) -> dict[str, Any]:  # type: ignore[misc]
         source_table_details = self.table.describe()["TableDescription"]
         source_table_details["TableCreationDateTime"] = source_table_details[
             "CreationDateTime"
@@ -1111,14 +1256,14 @@ class RestoredTable(Table):
         self.source_table_arn = backup.table.table_arn
         self.restore_date_time = self.created_at
 
-    def _parse_params_from_backup(self, backup: "Backup") -> Dict[str, Any]:
+    def _parse_params_from_backup(self, backup: "Backup") -> dict[str, Any]:
         return {
             "schema": copy.deepcopy(backup.table.schema),
             "attr": copy.deepcopy(backup.table.attr),
             "throughput": copy.deepcopy(backup.table.throughput),
         }
 
-    def describe(self, base_key: str = "TableDescription") -> Dict[str, Any]:
+    def describe(self, base_key: str = "TableDescription") -> dict[str, Any]:
         result = super().describe(base_key=base_key)
         result[base_key]["RestoreSummary"] = {
             "SourceBackupArn": self.source_backup_arn,
@@ -1140,14 +1285,14 @@ class RestoredPITTable(Table):
         self.source_table_arn = source.table_arn
         self.restore_date_time = self.created_at
 
-    def _parse_params_from_table(self, table: Table) -> Dict[str, Any]:
+    def _parse_params_from_table(self, table: Table) -> dict[str, Any]:
         return {
             "schema": copy.deepcopy(table.schema),
             "attr": copy.deepcopy(table.attr),
             "throughput": copy.deepcopy(table.throughput),
         }
 
-    def describe(self, base_key: str = "TableDescription") -> Dict[str, Any]:
+    def describe(self, base_key: str = "TableDescription") -> dict[str, Any]:
         result = super().describe(base_key=base_key)
         result[base_key]["RestoreSummary"] = {
             "SourceTableArn": self.source_table_arn,
@@ -1155,3 +1300,10 @@ class RestoredPITTable(Table):
             "RestoreInProgress": False,
         }
         return result
+
+
+class ResourcePolicy:
+    def __init__(self, resource_arn: str, policy_doc: str):
+        self.resource_arn = resource_arn
+        self.policy_doc = policy_doc
+        self.revision_id = str(int(unix_time_millis()))
