@@ -1,19 +1,31 @@
 import copy
 import itertools
 import json
+from collections.abc import Callable
 from functools import wraps
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Optional, Union
 
 from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
+from moto.dynamodb.comparisons import create_condition_expression_parser
 from moto.dynamodb.models import DynamoDBBackend, Table, dynamodb_backends
+from moto.dynamodb.models.table import (
+    DEFAULT_WARM_THROUGHPUT_RCU,
+    DEFAULT_WARM_THROUGHPUT_WCU,
+)
 from moto.dynamodb.models.utilities import dynamo_json_dump
-from moto.dynamodb.parsing.expressions import UpdateExpressionParser  # type: ignore
+from moto.dynamodb.parsing.expressions import (  # type: ignore
+    ExpressionAttributeName,
+    ExpressionAttributeValue,
+    UpdateExpressionParser,
+)
 from moto.dynamodb.parsing.key_condition_expression import parse_expression
 from moto.dynamodb.parsing.reserved_keywords import ReservedKeywords
+from moto.dynamodb.utils import find_duplicates
 from moto.utilities.aws_headers import amz_crc32
 
 from .exceptions import (
+    ExpressionAttributeValuesEmpty,
     InvalidProjectionExpression,
     KeyIsEmptyStringException,
     MockValidationException,
@@ -21,7 +33,6 @@ from .exceptions import (
     ResourceNotFoundException,
     UnknownKeyType,
 )
-from .utils import extract_duplicates
 
 TRANSACTION_MAX_ITEMS = 25
 
@@ -82,7 +93,7 @@ def include_consumed_capacity(
 
 
 def validate_put_has_empty_keys(
-    field_updates: Dict[str, Any], table: Table, custom_error_msg: Optional[str] = None
+    field_updates: dict[str, Any], table: Table, custom_error_msg: Optional[str] = None
 ) -> None:
     """
     Error if any keys have an empty value. Checks Global index attributes as well
@@ -122,9 +133,9 @@ def validate_put_has_empty_keys(
             raise MockValidationException(msg.format(empty_key))
 
 
-def validate_put_has_empty_attrs(field_updates: Dict[str, Any], table: Table) -> None:
+def validate_put_has_empty_attrs(field_updates: dict[str, Any], table: Table) -> None:
     # Example invalid attribute: [{'M': {'SS': {'NS': []}}}]
-    def _validate_attr(attr: Dict[str, Any]) -> None:
+    def _validate_attr(attr: dict[str, Any]) -> None:
         for set_type, error in [("NS", "number"), ("SS", "string")]:
             if set_type in attr and attr[set_type] == []:
                 raise MockValidationException(
@@ -142,7 +153,7 @@ def validate_put_has_empty_attrs(field_updates: Dict[str, Any], table: Table) ->
                 _validate_attr(val)
 
 
-def validate_put_has_gsi_keys_set_to_none(item: Dict[str, Any], table: Table) -> None:
+def validate_put_has_gsi_keys_set_to_none(item: dict[str, Any], table: Table) -> None:
     for gsi in table.global_indexes:
         for attr in gsi.schema:
             attr_name = attr["AttributeName"]
@@ -152,6 +163,18 @@ def validate_put_has_gsi_keys_set_to_none(item: Dict[str, Any], table: Table) ->
                 )
 
 
+def validate_attributes_used(
+    attribute_names: Optional[dict[str, Any]],
+    names_used: list[str],
+    provided_attr: str = "Names",
+) -> None:
+    for name in attribute_names or []:
+        if name not in names_used:
+            raise MockValidationException(
+                f"Value provided in ExpressionAttribute{provided_attr} unused in expressions: keys: {{{name}}}"
+            )
+
+
 def check_projection_expression(expression: str) -> None:
     if expression.upper() in ReservedKeywords.get_reserved_keywords():
         raise MockValidationException(
@@ -167,6 +190,45 @@ def check_projection_expression(expression: str) -> None:
         )
 
 
+class ProjectionExpressionParser:
+    def __init__(
+        self,
+        projection_expression: Optional[str],
+        expression_attribute_names: Optional[dict[str, str]],
+    ):
+        self.projection_expression = projection_expression
+        self.expression_attribute_names = (
+            expression_attribute_names if expression_attribute_names else {}
+        )
+
+        self.expr_attr_names_found: list[str] = []
+
+    def parse(self) -> list[list[str]]:
+        """
+        lvl1.lvl2.attr1,lvl1.attr2 --> [["lvl1", "lvl2", "attr1"], ["lvl1", "attr2]]
+        """
+
+        if self.projection_expression:
+            expressions = [x.strip() for x in self.projection_expression.split(",")]
+            duplicates = find_duplicates(expressions)
+            if duplicates:
+                raise InvalidProjectionExpression(*duplicates)
+            for expression in expressions:
+                check_projection_expression(expression)
+            output = []
+            for nested_expr in expressions:
+                nested_array = []
+                for expr in nested_expr.split("."):
+                    if self.expression_attribute_names.get(expr):
+                        self.expr_attr_names_found.append(expr)
+                        nested_array.append(self.expression_attribute_names[expr])
+                    else:
+                        nested_array.append(expr)
+                output.append(nested_array)
+            return output
+        return []
+
+
 class DynamoHandler(BaseResponse):
     def __init__(self) -> None:
         super().__init__(service_name="dynamodb")
@@ -204,7 +266,7 @@ class DynamoHandler(BaseResponse):
             limit, exclusive_start_table_name
         )
 
-        response: Dict[str, Any] = {"TableNames": tables}
+        response: dict[str, Any] = {"TableNames": tables}
         if last_eval:
             response["LastEvaluatedTableName"] = last_eval
 
@@ -227,6 +289,7 @@ class DynamoHandler(BaseResponse):
         streams = body.get("StreamSpecification")
         tags = body.get("Tags", [])
         deletion_protection_enabled = body.get("DeletionProtectionEnabled", False)
+        warm_throughput = body.get("WarmThroughput")
 
         self._validate_table_creation(
             billing_mode=billing_mode,
@@ -235,6 +298,7 @@ class DynamoHandler(BaseResponse):
             global_indexes=global_indexes,
             local_secondary_indexes=local_secondary_indexes,
             attr=attr,
+            warm_throughput=warm_throughput,
         )
 
         table = self.dynamodb_backend.create_table(
@@ -249,17 +313,19 @@ class DynamoHandler(BaseResponse):
             sse_specification=sse_spec,
             tags=tags,
             deletion_protection_enabled=deletion_protection_enabled,
+            warm_throughput=warm_throughput,
         )
         return dynamo_json_dump(table.describe())
 
     def _validate_table_creation(
         self,
         billing_mode: str,
-        throughput: Optional[Dict[str, Any]],
-        key_schema: List[Dict[str, str]],
-        global_indexes: Optional[List[Dict[str, Any]]],
-        local_secondary_indexes: Optional[List[Dict[str, Any]]],
-        attr: List[Dict[str, str]],
+        throughput: Optional[dict[str, Any]],
+        key_schema: list[dict[str, str]],
+        global_indexes: Optional[list[dict[str, Any]]],
+        local_secondary_indexes: Optional[list[dict[str, Any]]],
+        attr: list[dict[str, str]],
+        warm_throughput: Optional[dict[str, Any]],
     ) -> None:
         # Validate Throughput
         if billing_mode == "PAY_PER_REQUEST" and throughput:
@@ -293,6 +359,40 @@ class DynamoHandler(BaseResponse):
                 "One or more parameter values were invalid: List of GlobalSecondaryIndexes is empty"
             )
         for idx, g_idx in enumerate(global_indexes or [], start=1):
+            idx_throughput = g_idx.get("ProvisionedThroughput", None)
+            idx_warm_throughput = g_idx.get("WarmThroughput", None)
+            min_rcu = (
+                idx_throughput["ReadCapacityUnits"]
+                if idx_throughput
+                else DEFAULT_WARM_THROUGHPUT_RCU
+            )
+            min_wcu = (
+                idx_throughput["WriteCapacityUnits"]
+                if idx_throughput
+                else DEFAULT_WARM_THROUGHPUT_WCU
+            )
+
+            if idx_throughput:
+                error_rcu_end = "ReadCapacityUnits of ProvisionedThroughput"
+                error_wcu_end = "WriteCapacityUnits of ProvisionedThroughput"
+            else:
+                error_rcu_end = "initial throughput for OnDemand"
+                error_wcu_end = "initial throughput for OnDemand"
+
+            error_rcu = f"One or more parameter values were invalid: Requested ReadUnitsPerSecond for WarmThroughput for index {g_idx['IndexName']} is lower than {error_rcu_end}"
+            error_wcu = f"One or more parameter values were invalid: Requested WriteUnitsPerSecond for WarmThroughput for index {g_idx['IndexName']} is lower than {error_wcu_end}"
+
+            if (
+                idx_warm_throughput
+                and idx_warm_throughput.get("ReadUnitsPerSecond", min_rcu) < min_rcu
+            ):
+                raise MockValidationException(error_rcu)
+            if (
+                idx_warm_throughput
+                and idx_warm_throughput.get("WriteUnitsPerSecond", min_wcu) < min_wcu
+            ):
+                raise MockValidationException(error_wcu)
+
             for idx2, _key in enumerate(g_idx["KeySchema"], start=1):
                 key_type = _key["KeyType"]
                 if key_type not in ["HASH", "RANGE"]:
@@ -315,12 +415,12 @@ class DynamoHandler(BaseResponse):
         expected_attrs = []
         expected_attrs.extend([key["AttributeName"] for key in key_schema])
         local_key_schemas = itertools.chain(
-            *list(idx["KeySchema"] for idx in (local_secondary_indexes or []))
+            *[idx["KeySchema"] for idx in (local_secondary_indexes or [])]
         )
         expected_attrs.extend(schema["AttributeName"] for schema in local_key_schemas)
 
         global_key_schemas = itertools.chain(
-            *list(idx["KeySchema"] for idx in (global_indexes or []))
+            *[idx["KeySchema"] for idx in (global_indexes or [])]
         )
         expected_attrs.extend(schema["AttributeName"] for schema in global_key_schemas)
         expected_attrs = list(set(expected_attrs))
@@ -331,10 +431,43 @@ class DynamoHandler(BaseResponse):
         if actual_attrs != expected_attrs:
             self._throw_attr_error(actual_attrs, expected_attrs, has_index)
 
+        # Validate WarmThroughput
+        min_rcu = (
+            throughput["ReadCapacityUnits"]
+            if throughput
+            else DEFAULT_WARM_THROUGHPUT_RCU
+        )
+        min_wcu = (
+            throughput["WriteCapacityUnits"]
+            if throughput
+            else DEFAULT_WARM_THROUGHPUT_WCU
+        )
+
+        if throughput:
+            error_rcu_end = "ReadCapacityUnits of ProvisionedThroughput"
+            error_wcu_end = "WriteCapacityUnits of ProvisionedThroughput"
+        else:
+            error_rcu_end = "initial throughput for OnDemand"
+            error_wcu_end = "initial throughput for OnDemand"
+
+        error_rcu = f"One or more parameter values were invalid: Requested ReadUnitsPerSecond for WarmThroughput for table is lower than {error_rcu_end}"
+        error_wcu = f"One or more parameter values were invalid: Requested WriteUnitsPerSecond for WarmThroughput for table is lower than {error_wcu_end}"
+
+        if (
+            warm_throughput
+            and warm_throughput.get("ReadUnitsPerSecond", min_rcu) < min_rcu
+        ):
+            raise MockValidationException(error_rcu)
+        if (
+            warm_throughput
+            and warm_throughput.get("WriteUnitsPerSecond", min_wcu) < min_wcu
+        ):
+            raise MockValidationException(error_wcu)
+
     def _throw_attr_error(
-        self, actual_attrs: List[str], expected_attrs: List[str], indexes: bool
+        self, actual_attrs: list[str], expected_attrs: list[str], indexes: bool
     ) -> None:
-        def dump_list(list_: List[str]) -> str:
+        def dump_list(list_: list[str]) -> str:
             return str(list_).replace("'", "")
 
         err_head = "One or more parameter values were invalid: "
@@ -446,6 +579,7 @@ class DynamoHandler(BaseResponse):
         billing_mode = self.body.get("BillingMode", None)
         stream_spec = self.body.get("StreamSpecification", None)
         deletion_protection_enabled = self.body.get("DeletionProtectionEnabled")
+        warm_throughput = self.body.get("WarmThroughput")
         table = self.dynamodb_backend.update_table(
             name=name,
             attr_definitions=attr_definitions,
@@ -454,6 +588,7 @@ class DynamoHandler(BaseResponse):
             billing_mode=billing_mode,
             stream_spec=stream_spec,
             deletion_protection_enabled=deletion_protection_enabled,
+            warm_throughput=warm_throughput,
         )
         return dynamo_json_dump(table.describe())
 
@@ -498,6 +633,16 @@ class DynamoHandler(BaseResponse):
         expression_attribute_names = self.body.get("ExpressionAttributeNames", {})
         expression_attribute_values = self._get_expr_attr_values()
 
+        parser = create_condition_expression_parser(
+            condition_expression,
+            expression_attribute_names,
+            expression_attribute_values,
+        )
+        parser.parse()
+        validate_attributes_used(
+            expression_attribute_names, parser.expr_attr_names_found
+        )
+
         if condition_expression:
             overwrite = False
 
@@ -582,23 +727,25 @@ class DynamoHandler(BaseResponse):
             )
 
         expression_attribute_names = self.body.get("ExpressionAttributeNames")
+        if projection_expression is None and expression_attribute_names:
+            raise MockValidationException(
+                "ExpressionAttributeNames can only be specified when using expressions"
+            )
         if expression_attribute_names == {}:
-            if projection_expression is None:
-                raise MockValidationException(
-                    "ExpressionAttributeNames can only be specified when using expressions"
-                )
-            else:
-                raise MockValidationException(
-                    "ExpressionAttributeNames must not be empty"
-                )
+            raise MockValidationException("ExpressionAttributeNames must not be empty")
 
-        if not all([k in table.attribute_keys for k in key]):
+        if not all(k in table.attribute_keys for k in key):
             raise ProvidedKeyDoesNotExist
 
         expression_attribute_names = expression_attribute_names or {}
-        projection_expressions = self._adjust_projection_expression(
+        parser = ProjectionExpressionParser(
             projection_expression, expression_attribute_names
         )
+        projection_expressions = parser.parse()
+
+        validate_attributes_used(
+            expression_attribute_names, parser.expr_attr_names_found
+        )
 
         item = self.dynamodb_backend.get_item(name, key, projection_expressions)
         if item:
@@ -611,7 +758,7 @@ class DynamoHandler(BaseResponse):
     def batch_get_item(self) -> str:
         table_batches = self.body["RequestItems"]
 
-        results: Dict[str, Any] = {
+        results: dict[str, Any] = {
             "ConsumedCapacity": [],
             "Responses": {},
             "UnprocessedKeys": {},
@@ -648,9 +795,13 @@ class DynamoHandler(BaseResponse):
                 "ExpressionAttributeNames", {}
             )
 
-            projection_expressions = self._adjust_projection_expression(
+            parser = ProjectionExpressionParser(
                 projection_expression, expression_attribute_names
             )
+            projection_expressions = parser.parse()
+            validate_attributes_used(
+                expression_attribute_names, parser.expr_attr_names_found
+            )
 
             results["Responses"][table_name] = []
             for key in keys:
@@ -674,7 +825,7 @@ class DynamoHandler(BaseResponse):
             )
         return dynamo_json_dump(results)
 
-    def _contains_duplicates(self, keys: List[str]) -> bool:
+    def _contains_duplicates(self, keys: list[str]) -> bool:
         unique_keys = []
         for k in keys:
             if k in unique_keys:
@@ -692,9 +843,17 @@ class DynamoHandler(BaseResponse):
         filter_expression = self._get_filter_expression()
         expression_attribute_values = self._get_expr_attr_values()
 
-        projection_expressions = self._adjust_projection_expression(
+        condition_parser = create_condition_expression_parser(
+            filter_expression, expression_attribute_names, expression_attribute_values
+        )
+        condition_parser.parse()
+        expression_attribute_names_used = condition_parser.expr_attr_names_found
+
+        projection_parser = ProjectionExpressionParser(
             projection_expression, expression_attribute_names
         )
+        projection_expressions = projection_parser.parse()
+        expression_attribute_names_used += projection_parser.expr_attr_names_found
 
         filter_kwargs = {}
 
@@ -703,12 +862,20 @@ class DynamoHandler(BaseResponse):
             schema = self.dynamodb_backend.get_schema(
                 table_name=name, index_name=index_name
             )
-            hash_key, range_comparison, range_values = parse_expression(
+            (
+                hash_key,
+                range_comparison,
+                range_values,
+                expression_attribute_names_used_by_key_condition,
+            ) = parse_expression(
                 key_condition_expression=key_condition_expression,
                 expression_attribute_names=expression_attribute_names,
                 expression_attribute_values=expression_attribute_values,
                 schema=schema,
             )
+            expression_attribute_names_used += (
+                expression_attribute_names_used_by_key_condition
+            )
         else:
             # 'KeyConditions': {u'forum_name': {u'ComparisonOperator': u'EQ', u'AttributeValueList': [{u'S': u'the-key'}]}}
             key_conditions = self.body.get("KeyConditions")
@@ -748,6 +915,10 @@ class DynamoHandler(BaseResponse):
                             range_values = []
             if query_filters:
                 filter_kwargs.update(query_filters)
+
+        validate_attributes_used(
+            expression_attribute_names, expression_attribute_names_used
+        )
         index_name = self.body.get("IndexName")
         exclusive_start_key = self.body.get("ExclusiveStartKey")
         limit = self.body.get("Limit")
@@ -771,7 +942,7 @@ class DynamoHandler(BaseResponse):
             **filter_kwargs,
         )
 
-        result: Dict[str, Any] = {
+        result: dict[str, Any] = {
             "Count": len(items),
             "ScannedCount": scanned_count,
         }
@@ -784,30 +955,6 @@ class DynamoHandler(BaseResponse):
 
         return dynamo_json_dump(result)
 
-    def _adjust_projection_expression(
-        self, projection_expression: Optional[str], expr_attr_names: Dict[str, str]
-    ) -> List[List[str]]:
-        """
-        lvl1.lvl2.attr1,lvl1.attr2 --> [["lvl1", "lvl2", "attr1"], ["lvl1", "attr2]]
-        """
-
-        def _adjust(expression: str) -> str:
-            return (expr_attr_names or {}).get(expression, expression)
-
-        if projection_expression:
-            expressions = [x.strip() for x in projection_expression.split(",")]
-            duplicates = extract_duplicates(expressions)
-            if duplicates:
-                raise InvalidProjectionExpression(duplicates)
-            for expression in expressions:
-                check_projection_expression(expression)
-            return [
-                [_adjust(expr) for expr in nested_expr.split(".")]
-                for nested_expr in expressions
-            ]
-
-        return []
-
     @include_consumed_capacity()
     def scan(self) -> str:
         name = self.body["TableName"]
@@ -824,7 +971,25 @@ class DynamoHandler(BaseResponse):
         filter_expression = self._get_filter_expression()
         expression_attribute_values = self._get_expr_attr_values()
         expression_attribute_names = self.body.get("ExpressionAttributeNames", {})
+
+        filter_parser = create_condition_expression_parser(
+            filter_expression,
+            expression_attribute_names,
+            expression_attribute_values,
+        )
+        try:
+            filter_parser.parse()
+        except ValueError as err:
+            raise MockValidationException(f"Bad Filter Expression: {err}")
+        expression_attribute_names_used = filter_parser.expr_attr_names_found
+
         projection_expression = self._get_projection_expression()
+        projection_parser = ProjectionExpressionParser(
+            projection_expression, expression_attribute_names
+        )
+        projection_expressions = projection_parser.parse()
+        expression_attribute_names_used += projection_parser.expr_attr_names_found
+
         exclusive_start_key = self.body.get("ExclusiveStartKey")
         limit = self.body.get("Limit")
         index_name = self.body.get("IndexName")
@@ -848,8 +1013,8 @@ class DynamoHandler(BaseResponse):
                 f"The Segment parameter is zero-based and must be less than parameter TotalSegments: Segment: {segment} is not less than TotalSegments: {total_segments}"
             )
 
-        projection_expressions = self._adjust_projection_expression(
-            projection_expression, expression_attribute_names
+        validate_attributes_used(
+            expression_attribute_names, expression_attribute_names_used
         )
 
         try:
@@ -878,6 +1043,7 @@ class DynamoHandler(BaseResponse):
             result["LastEvaluatedKey"] = last_evaluated_key
         return dynamo_json_dump(result)
 
+    @include_consumed_capacity()
     def delete_item(self) -> str:
         name = self.body["TableName"]
         key = self.body["Key"]
@@ -886,7 +1052,7 @@ class DynamoHandler(BaseResponse):
             raise MockValidationException("Return values set to invalid value")
 
         table = self.dynamodb_backend.get_table(name)
-        if not all([k in table.attribute_keys for k in key]):
+        if not all(k in table.attribute_keys for k in key):
             raise ProvidedKeyDoesNotExist
 
         # Attempt to parse simple ConditionExpressions into an Expected
@@ -898,6 +1064,16 @@ class DynamoHandler(BaseResponse):
             "ReturnValuesOnConditionCheckFailure"
         )
 
+        parser = create_condition_expression_parser(
+            condition_expression,
+            expression_attribute_names,
+            expression_attribute_values,
+        )
+        parser.parse()
+        validate_attributes_used(
+            expression_attribute_names, parser.expr_attr_names_found
+        )
+
         item = self.dynamodb_backend.delete_item(
             name,
             key,
@@ -926,15 +1102,31 @@ class DynamoHandler(BaseResponse):
             )
 
         table = self.dynamodb_backend.get_table(name)
-        if not all([k in table.attribute_keys for k in key]):
+        if not all(k in table.attribute_keys for k in key):
             raise ProvidedKeyDoesNotExist
 
+        expression_attribute_names_used = []
+        expression_attribute_values_used = []
         if update_expression is not None:
             update_expression = update_expression.strip()
             if update_expression == "":
                 raise MockValidationException(
                     "Invalid UpdateExpression: The expression can not be empty;"
                 )
+            update_expression_ast = UpdateExpressionParser.make(update_expression)
+            attr_name_clauses = update_expression_ast.find_clauses(
+                [ExpressionAttributeName]
+            )
+            expression_attribute_names_used = [
+                attr.get_attribute_name_placeholder() for attr in attr_name_clauses
+            ]
+            attr_value_clauses = update_expression_ast.find_clauses(
+                [ExpressionAttributeValue]
+            )
+            expression_attribute_values_used.extend(
+                [attr.get_value_name() for attr in attr_value_clauses]
+            )
+
         else:
             update_expression = ""
 
@@ -967,6 +1159,20 @@ class DynamoHandler(BaseResponse):
         condition_expression = self.body.get("ConditionExpression")
         expression_attribute_names = self.body.get("ExpressionAttributeNames", {})
         expression_attribute_values = self._get_expr_attr_values()
+        condition_parser = create_condition_expression_parser(
+            condition_expression,
+            expression_attribute_names,
+            expression_attribute_values,
+        )
+        condition_parser.parse()
+        expression_attribute_names_used += condition_parser.expr_attr_names_found
+        expression_attribute_values_used += condition_parser.expr_attr_values_found
+        validate_attributes_used(
+            expression_attribute_names, expression_attribute_names_used
+        )
+        validate_attributes_used(
+            expression_attribute_values, expression_attribute_values_used, "Values"
+        )
 
         item = self.dynamodb_backend.update_item(
             name,
@@ -1007,21 +1213,25 @@ class DynamoHandler(BaseResponse):
             )
         return dynamo_json_dump(item_dict)
 
-    def _get_expr_attr_values(self) -> Dict[str, Dict[str, str]]:
+    def _get_expr_attr_values(self) -> dict[str, dict[str, str]]:
         values = self.body.get("ExpressionAttributeValues")
         if values is None:
             return {}
         if len(values) == 0:
-            raise MockValidationException("ExpressionAttributeValues must not be empty")
-        for key in values.keys():
+            raise ExpressionAttributeValuesEmpty
+        for key in values:
             if not key.startswith(":"):
                 raise MockValidationException(
                     f'ExpressionAttributeValues contains invalid key: Syntax error; key: "{key}"'
                 )
+            if values[key] == {"NS": []}:
+                raise MockValidationException(
+                    f"ExpressionAttributeValues contains invalid value: One or more parameter values were invalid: An number set  may not be empty for key {key}"
+                )
         return values
 
     def _build_updated_new_attributes(self, original: Any, changed: Any) -> Any:
-        if type(changed) != type(original):
+        if type(changed) is not type(original):
             return changed
         else:
             if isinstance(changed, dict):
@@ -1071,30 +1281,28 @@ class DynamoHandler(BaseResponse):
 
     def transact_get_items(self) -> str:
         transact_items = self.body["TransactItems"]
-        responses: List[Dict[str, Any]] = list()
+        responses: list[dict[str, Any]] = []
 
         if len(transact_items) > TRANSACTION_MAX_ITEMS:
             msg = "1 validation error detected: Value '["
-            err_list = list()
+            err_list = []
             request_id = 268435456
             for _ in transact_items:
                 request_id += 1
                 hex_request_id = format(request_id, "x")
                 err_list.append(
-                    "com.amazonaws.dynamodb.v20120810.TransactGetItem@%s"
-                    % hex_request_id
+                    f"com.amazonaws.dynamodb.v20120810.TransactGetItem@{hex_request_id}"
                 )
             msg += ", ".join(err_list)
             msg += (
                 "'] at 'transactItems' failed to satisfy constraint: "
-                "Member must have length less than or equal to %s"
-                % TRANSACTION_MAX_ITEMS
+                f"Member must have length less than or equal to {TRANSACTION_MAX_ITEMS}"
             )
 
             raise MockValidationException(msg)
 
         ret_consumed_capacity = self.body.get("ReturnConsumedCapacity", "NONE")
-        consumed_capacity: Dict[str, Any] = dict()
+        consumed_capacity: dict[str, Any] = {}
 
         for transact_item in transact_items:
             table_name = transact_item["Get"]["TableName"]
@@ -1122,10 +1330,10 @@ class DynamoHandler(BaseResponse):
                     "ReadCapacityUnits": read_capacity_units,
                 }
 
-        result = dict()
+        result = {}
         result.update({"Responses": responses})
         if ret_consumed_capacity != "NONE":
-            result.update({"ConsumedCapacity": [v for v in consumed_capacity.values()]})
+            result.update({"ConsumedCapacity": list(consumed_capacity.values())})
 
         return dynamo_json_dump(result)
 
@@ -1133,11 +1341,36 @@ class DynamoHandler(BaseResponse):
         transact_items = self.body["TransactItems"]
         # Validate first - we should error before we start the transaction
         for item in transact_items:
+            # This logic is common among all types of write items
+            item_values = list(item.values())[
+                0
+            ]  # Each item only has one of Put, Update, Delete, ConditionCheck
+            condition_expression = item_values.get("ConditionExpression")
+            expression_attribute_names = item_values.get("ExpressionAttributeNames", {})
+            expression_attribute_values = item_values.get(
+                "ExpressionAttributeValues", {}
+            )
+
+            parser = create_condition_expression_parser(
+                condition_expression,
+                expression_attribute_names,
+                expression_attribute_values,
+            )
+            parser.parse()
+            expression_attribute_names_used = parser.expr_attr_names_found
+
             if "Put" in item:
+                if item["Put"].get("ExpressionAttributeValues") == {}:
+                    raise ExpressionAttributeValuesEmpty
+
                 item_attrs = item["Put"]["Item"]
                 table = self.dynamodb_backend.get_table(item["Put"]["TableName"])
                 validate_put_has_empty_keys(item_attrs, table)
+
             if "Update" in item:
+                if item["Update"].get("ExpressionAttributeValues") == {}:
+                    raise ExpressionAttributeValuesEmpty
+
                 item_attrs = item["Update"]["Key"]
                 table = self.dynamodb_backend.get_table(item["Update"]["TableName"])
                 validate_put_has_empty_keys(
@@ -1145,12 +1378,22 @@ class DynamoHandler(BaseResponse):
                     table,
                     custom_error_msg="One or more parameter values are not valid. The AttributeValue for a key attribute cannot contain an empty string value. Key: {}",
                 )
+
                 update_expression = item["Update"]["UpdateExpression"]
-                UpdateExpressionParser.make(update_expression).validate(
-                    limit_set_actions=True
+                update_expression_ast = UpdateExpressionParser.make(update_expression)
+                attr_name_clauses = update_expression_ast.find_clauses(
+                    [ExpressionAttributeName]
                 )
+                expression_attribute_names_used += [
+                    attr.get_attribute_name_placeholder() for attr in attr_name_clauses
+                ]
+
+            validate_attributes_used(
+                expression_attribute_names, expression_attribute_names_used
+            )
+
         self.dynamodb_backend.transact_write_items(transact_items)
-        response: Dict[str, Any] = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
+        response: dict[str, Any] = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
         return dynamo_json_dump(response)
 
     def describe_continuous_backups(self) -> str:
@@ -1255,6 +1498,7 @@ class DynamoHandler(BaseResponse):
             global_indexes=global_indexes,
             local_secondary_indexes=None,
             attr=table_attrs,
+            warm_throughput=None,
         )
 
         import_table = self.dynamodb_backend.import_table(
