@@ -1,4 +1,5 @@
 import copy
+import ipaddress
 import json
 import re
 import sys
@@ -7,7 +8,7 @@ from collections import OrderedDict
 from enum import Enum, unique
 from json import JSONDecodeError
 from operator import eq, ge, gt, le, lt
-from typing import TYPE_CHECKING, Any, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Optional
 
 import requests
 
@@ -73,7 +74,7 @@ class Rule(CloudFormationModel):
         event_bus_name: str,
         state: Optional[str],
         managed_by: Optional[str] = None,
-        targets: Optional[List[Dict[str, Any]]] = None,
+        targets: Optional[list[dict[str, Any]]] = None,
     ):
         self.name = name
         self.account_id = account_id
@@ -119,7 +120,7 @@ class Rule(CloudFormationModel):
         self.remove_targets([t["Id"] for t in self.targets])
         event_backend.delete_rule(name=self.name, event_bus_arn=self.event_bus_name)
 
-    def put_targets(self, targets: List[Dict[str, Any]]) -> None:
+    def put_targets(self, targets: list[dict[str, Any]]) -> None:
         # Not testing for valid ARNs.
         for target in targets:
             index = self._check_target_exists(target["Id"])
@@ -128,7 +129,7 @@ class Rule(CloudFormationModel):
             else:
                 self.targets.append(target)
 
-    def remove_targets(self, ids: List[str]) -> None:
+    def remove_targets(self, ids: list[str]) -> None:
         for target_id in ids:
             index = self._check_target_exists(target_id)
             if index is not None:
@@ -198,7 +199,7 @@ class Rule(CloudFormationModel):
             else:
                 raise NotImplementedError(f"Expr not defined for {type(self)}")
 
-    def _send_to_cw_log_group(self, name: str, event: Dict[str, Any]) -> None:
+    def _send_to_cw_log_group(self, name: str, event: dict[str, Any]) -> None:
         from moto.logs import logs_backends
 
         if "time" in event:
@@ -224,12 +225,12 @@ class Rule(CloudFormationModel):
             archive.events.append(event)  # type: ignore[union-attr]
 
     def _find_api_destination(self, resource_id: str) -> "Destination":
-        backend: "EventsBackend" = events_backends[self.account_id][self.region_name]
+        backend: EventsBackend = events_backends[self.account_id][self.region_name]
         destination_name = resource_id.split("/")[0]
         return backend.destinations[destination_name]
 
     def _send_to_sqs_queue(
-        self, resource_id: str, event: Dict[str, Any], group_id: Optional[str] = None
+        self, resource_id: str, event: dict[str, Any], group_id: Optional[str] = None
     ) -> None:
         from moto.sqs import sqs_backends
 
@@ -245,8 +246,8 @@ class Rule(CloudFormationModel):
             )
             if queue_attr["ContentBasedDeduplication"] == "false":
                 warnings.warn(
-                    "To let EventBridge send messages to your SQS FIFO queue, "
-                    "you must enable content-based deduplication."
+                    "To let EventBridge send messages to your SQS FIFO queue, you must enable content-based deduplication.",
+                    stacklevel=2,
                 )
                 return
 
@@ -302,7 +303,7 @@ class Rule(CloudFormationModel):
         event_bus_arn = properties.get("EventBusName")
         tags = properties.get("Tags")
 
-        backend: "EventsBackend" = events_backends[account_id][region_name]
+        backend: EventsBackend = events_backends[account_id][region_name]
         rule = backend.put_rule(
             event_name,
             scheduled_expression=scheduled_expression,
@@ -352,7 +353,7 @@ class Rule(CloudFormationModel):
 
         event_backend.delete_rule(resource_name, event_bus_arn)
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         attributes = {
             "Arn": self.arn,
             "CreatedBy": self.created_by,
@@ -379,8 +380,8 @@ class EventBus(CloudFormationModel):
         name: str,
         description: Optional[str] = None,
         kms_key_identifier: Optional[str] = None,
-        dead_letter_config: Optional[Dict[str, str]] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        dead_letter_config: Optional[dict[str, str]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
     ):
         self.account_id = account_id
         self.region = region_name
@@ -395,8 +396,8 @@ class EventBus(CloudFormationModel):
         self.creation_time = unix_time()
         self.last_modified_time = self.creation_time
 
-        self._statements: Dict[str, EventBusPolicyStatement] = {}
-        self.rules: Dict[str, Rule] = OrderedDict()
+        self._statements: dict[str, EventBusPolicyStatement] = {}
+        self.rules: dict[str, Rule] = OrderedDict()
 
     @property
     def policy(self) -> Optional[str]:
@@ -502,8 +503,8 @@ class EventBus(CloudFormationModel):
         self,
         statement_id: str,
         action: str,
-        principal: Dict[str, str],
-        condition: Optional[Dict[str, Any]],
+        principal: dict[str, str],
+        condition: Optional[dict[str, Any]],
     ) -> None:
         self._remove_principals_statements(principal)
         statement = EventBusPolicyStatement(
@@ -515,7 +516,7 @@ class EventBus(CloudFormationModel):
         )
         self._statements[statement_id] = statement
 
-    def add_policy(self, policy: Dict[str, Any]) -> None:
+    def add_policy(self, policy: dict[str, Any]) -> None:
         policy_statements = policy["Statement"]
 
         principals = [stmt["Principal"] for stmt in policy_statements]
@@ -536,11 +537,11 @@ class EventBusPolicyStatement:
     def __init__(
         self,
         sid: str,
-        principal: Dict[str, str],
+        principal: dict[str, str],
         action: str,
         resource: str,
         effect: str = "Allow",
-        condition: Optional[Dict[str, Any]] = None,
+        condition: Optional[dict[str, Any]] = None,
     ):
         self.sid = sid
         self.principal = principal
@@ -549,28 +550,28 @@ class EventBusPolicyStatement:
         self.effect = effect
         self.condition = condition
 
-    def describe(self) -> Dict[str, Any]:
-        statement: Dict[str, Any] = dict(
-            Sid=self.sid,
-            Effect=self.effect,
-            Principal=self.principal,
-            Action=self.action,
-            Resource=self.resource,
-        )
+    def describe(self) -> dict[str, Any]:
+        statement: dict[str, Any] = {
+            "Sid": self.sid,
+            "Effect": self.effect,
+            "Principal": self.principal,
+            "Action": self.action,
+            "Resource": self.resource,
+        }
 
         if self.condition:
             statement["Condition"] = self.condition
         return statement
 
     @classmethod
-    def from_dict(cls, statement_dict: Dict[str, Any]) -> "EventBusPolicyStatement":  # type: ignore[misc]
-        params = dict(
-            sid=statement_dict["Sid"],
-            effect=statement_dict["Effect"],
-            principal=statement_dict["Principal"],
-            action=statement_dict["Action"],
-            resource=statement_dict["Resource"],
-        )
+    def from_dict(cls, statement_dict: dict[str, Any]) -> "EventBusPolicyStatement":  # type: ignore[misc]
+        params = {
+            "sid": statement_dict["Sid"],
+            "effect": statement_dict["Effect"],
+            "principal": statement_dict["Principal"],
+            "action": statement_dict["Action"],
+            "resource": statement_dict["Resource"],
+        }
         condition = statement_dict.get("Condition")
         if condition:
             params["condition"] = condition
@@ -611,11 +612,11 @@ class Archive(CloudFormationModel):
         self.state = "ENABLED"
         self.uuid = str(random.uuid4())
 
-        self.events: List[EventMessageType] = []
+        self.events: list[EventMessageType] = []
         self.event_bus_name = source_arn.split("/")[-1]
         self.rule: Optional[Rule] = None
 
-    def describe_short(self) -> Dict[str, Any]:
+    def describe_short(self) -> dict[str, Any]:
         return {
             "ArchiveName": self.name,
             "EventSourceArn": self.source_arn,
@@ -626,7 +627,7 @@ class Archive(CloudFormationModel):
             "CreationTime": self.creation_time,
         }
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         result = {
             "ArchiveArn": self.arn,
             "Description": self.description,
@@ -748,7 +749,7 @@ class Replay(BaseModel):
         source_arn: str,
         start_time: str,
         end_time: str,
-        destination: Dict[str, Any],
+        destination: dict[str, Any],
     ):
         self.account_id = account_id
         self.region = region_name
@@ -764,7 +765,7 @@ class Replay(BaseModel):
         self.start_time = unix_time()
         self.end_time: Optional[float] = None
 
-    def describe_short(self) -> Dict[str, Any]:
+    def describe_short(self) -> dict[str, Any]:
         return {
             "ReplayName": self.name,
             "EventSourceArn": self.source_arn,
@@ -775,7 +776,7 @@ class Replay(BaseModel):
             "ReplayEndTime": self.end_time,
         }
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         result = {
             "ReplayArn": self.arn,
             "Description": self.description,
@@ -813,7 +814,7 @@ class Connection(BaseModel):
         region_name: str,
         description: str,
         authorization_type: str,
-        auth_parameters: Dict[str, Any],
+        auth_parameters: dict[str, Any],
     ):
         self.uuid = random.uuid4()
         self.name = name
@@ -843,7 +844,7 @@ class Connection(BaseModel):
         self.secret_arn = secret.arn
         self.arn = f"arn:{get_partition(region_name)}:events:{region_name}:{account_id}:connection/{connection_id}"
 
-    def describe_short(self) -> Dict[str, Any]:
+    def describe_short(self) -> dict[str, Any]:
         """
         Create the short description for the Connection object.
 
@@ -866,7 +867,7 @@ class Connection(BaseModel):
             "CreationTime": self.creation_time,
         }
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         """
         Create a complete description for the Connection object.
 
@@ -920,7 +921,7 @@ class Destination(BaseModel):
         self.state = "ACTIVE"
         self.arn = f"arn:{get_partition(region_name)}:events:{region_name}:{account_id}:api-destination/{name}/{self.uuid}"
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "ApiDestinationArn": self.arn,
             "ApiDestinationState": self.state,
@@ -934,7 +935,7 @@ class Destination(BaseModel):
             "Name": self.name,
         }
 
-    def describe_short(self) -> Dict[str, Any]:
+    def describe_short(self) -> dict[str, Any]:
         return {
             "ApiDestinationArn": self.arn,
             "ApiDestinationState": self.state,
@@ -944,71 +945,181 @@ class Destination(BaseModel):
 
 
 class EventPattern:
-    def __init__(self, raw_pattern: Optional[str], pattern: Dict[str, Any]):
+    def __init__(self, raw_pattern: Optional[str], pattern: dict[str, Any]):
         self._raw_pattern = raw_pattern
         self._pattern = pattern
 
-    def get_pattern(self) -> Dict[str, Any]:
+    def get_pattern(self) -> dict[str, Any]:
         return self._pattern
 
     def matches_event(self, event: EventMessageType) -> bool:
         if not self._pattern:
             return True
         event = json.loads(json.dumps(event))
-        return self._does_event_match(event, self._pattern)
-
-    def _does_event_match(
-        self, event: EventMessageType, pattern: Dict[str, Any]
-    ) -> bool:
-        items_and_filters = [(event.get(k, UNDEFINED), v) for k, v in pattern.items()]
-        nested_filter_matches = [
-            self._does_event_match(item, nested_filter)  # type: ignore
-            for item, nested_filter in items_and_filters
-            if isinstance(nested_filter, dict)
-        ]
-        filter_list_matches = [
-            self._does_item_match_filters(item, filter_list)
-            for item, filter_list in items_and_filters
-            if isinstance(filter_list, list)
-        ]
-        return all(nested_filter_matches + filter_list_matches)
-
-    def _does_item_match_filters(self, item: Any, filters: Any) -> bool:
-        allowed_values = [value for value in filters if isinstance(value, str)]
-        allowed_values_match = item in allowed_values if allowed_values else True
-        full_match = isinstance(item, list) and item == allowed_values
-        named_filter_matches = [
-            self._does_item_match_named_filter(item, pattern)
-            for pattern in filters
-            if isinstance(pattern, dict)
-        ]
-        return (full_match or allowed_values_match) and all(named_filter_matches)
+        event_flat = self._flatten_dict(event)
+        return self._does_event_match(event_flat, self._pattern)
 
     @staticmethod
-    def _does_item_match_named_filter(item: Any, pattern: Any) -> bool:  # type: ignore[misc]
+    def _flatten_dict(
+        node: Any, prefix: str = "", result: Optional[dict[str, Any]] = None
+    ) -> dict[str, Any]:
+        if result is None:
+            result = {}
+        if isinstance(node, dict):
+            for k, v in node.items():
+                new_key = f"{prefix}.{k}" if prefix else k
+                if isinstance(v, dict) and v:
+                    EventPattern._flatten_dict(v, new_key, result)
+                else:
+                    result[new_key] = v
+        return result
+
+    def _does_event_match(
+        self, event_flat: dict[str, Any], pattern_node: dict[str, Any], prefix: str = ""
+    ) -> bool:
+        if not isinstance(pattern_node, dict):
+            return False
+
+        results = []
+        for k, v in pattern_node.items():
+            if k == "$or":
+                results.append(
+                    any(self._does_event_match(event_flat, p, prefix) for p in v)
+                )
+            else:
+                new_prefix = f"{prefix}.{k}" if prefix else k
+                if isinstance(v, dict):
+                    # v is a nested pattern
+                    results.append(self._does_event_match(event_flat, v, new_prefix))
+                elif isinstance(v, list):
+                    # v is a list of filters (scalars or named filter dicts)
+                    item = event_flat.get(new_prefix, UNDEFINED)
+                    results.append(self._does_item_match_filters(item, v))
+                else:
+                    results.append(False)
+        return all(results)
+
+    def _does_item_match_filters(self, item: Any, filters: list[Any]) -> bool:
+        for f in filters:
+            if isinstance(f, (str, bool, int, float)) or f is None:
+                if item is UNDEFINED:
+                    continue
+                if isinstance(item, list):
+                    if f in item:
+                        return True
+                elif item == f:
+                    return True
+            elif isinstance(f, dict):
+                if self._does_item_match_named_filter(item, f):
+                    return True
+        return False
+
+    @staticmethod
+    def _does_item_match_named_filter(item: Any, pattern: dict[str, Any]) -> bool:
         filter_name, filter_value = list(pattern.items())[0]
         if filter_name == "exists":
-            is_leaf_node = not isinstance(item, dict)
-            leaf_exists = is_leaf_node and item is not UNDEFINED
-            should_exist = filter_value
-            return leaf_exists if should_exist else not leaf_exists
-        if filter_name == "prefix":
-            prefix = filter_value
-            return item.startswith(prefix)
-        if filter_name == "numeric":
-            as_function = {"<": lt, "<=": le, "=": eq, ">=": ge, ">": gt}
-            operators_and_values = zip(filter_value[::2], filter_value[1::2])
-            numeric_matches = [
-                as_function[operator](item, value)
-                for operator, value in operators_and_values
-            ]
-            return all(numeric_matches)
-        else:
-            warnings.warn(
-                f"'{filter_name}' filter logic unimplemented. defaulting to True"
-            )
+            exists = item is not UNDEFINED
+            return exists == filter_value
+
+        if item is UNDEFINED:
+            return False
+
+        def evaluate(val: Any) -> bool:
+            if filter_name == "prefix":
+                if (
+                    isinstance(filter_value, dict)
+                    and "equals-ignore-case" in filter_value
+                ):
+                    target = filter_value["equals-ignore-case"]
+                    return isinstance(val, str) and val.lower().startswith(
+                        target.lower()
+                    )
+                if isinstance(filter_value, list):
+                    return isinstance(val, str) and any(
+                        val.startswith(v) for v in filter_value
+                    )
+                return isinstance(val, str) and val.startswith(filter_value)
+            if filter_name == "suffix":
+                if (
+                    isinstance(filter_value, dict)
+                    and "equals-ignore-case" in filter_value
+                ):
+                    target = filter_value["equals-ignore-case"]
+                    return isinstance(val, str) and val.lower().endswith(target.lower())
+                if isinstance(filter_value, list):
+                    return isinstance(val, str) and any(
+                        val.endswith(v) for v in filter_value
+                    )
+                return isinstance(val, str) and val.endswith(filter_value)
+            if filter_name == "equals-ignore-case":
+                if isinstance(filter_value, list):
+                    return isinstance(val, str) and any(
+                        val.lower() == v.lower() for v in filter_value
+                    )
+                return isinstance(val, str) and val.lower() == filter_value.lower()
+            if filter_name == "numeric":
+                if not isinstance(val, (int, float)):
+                    return False
+                as_function = {"<": lt, "<=": le, "=": eq, ">=": ge, ">": gt}
+                operators_and_values = zip(filter_value[::2], filter_value[1::2])
+                numeric_matches = [
+                    as_function[operator](val, value)
+                    for operator, value in operators_and_values
+                ]
+                return all(numeric_matches)
+            if filter_name == "anything-but":
+                if isinstance(filter_value, list):
+                    return val not in filter_value
+                if isinstance(filter_value, dict):
+                    # Recursive check for any-but with other filters (e.g. prefix)
+                    return not EventPattern._does_item_match_named_filter(
+                        val, filter_value
+                    )
+                return val != filter_value
+            if filter_name == "cidr":
+                try:
+                    ip_item = ipaddress.ip_address(val)
+                    network = ipaddress.ip_network(filter_value)
+                    return ip_item in network
+                except Exception:
+                    return False
+            if filter_name == "wildcard":
+                if isinstance(filter_value, list):
+                    return any(
+                        EventPattern._wildcard_match(val, v) for v in filter_value
+                    )
+                return EventPattern._wildcard_match(val, filter_value)
             return True
 
+        if isinstance(item, list):
+            return any(evaluate(i) for i in item)
+        return evaluate(item)
+
+    @staticmethod
+    def _wildcard_match(item: Any, pattern: str) -> bool:
+        if not isinstance(item, str):
+            return False
+        regex = ""
+        i = 0
+        while i < len(pattern):
+            c = pattern[i]
+            if c == "\\":
+                if i + 1 < len(pattern):
+                    next_c = pattern[i + 1]
+                    if next_c in ["*", "\\"]:
+                        regex += re.escape(next_c)
+                        i += 2
+                        continue
+                regex += re.escape(c)
+                i += 1
+            elif c == "*":
+                regex += ".*"
+                i += 1
+            else:
+                regex += re.escape(c)
+                i += 1
+        return re.fullmatch(regex, item) is not None
+
     @classmethod
     def load(cls, raw_pattern: Optional[str]) -> "EventPattern":
         parser = EventPatternParser(raw_pattern)
@@ -1023,7 +1134,7 @@ class EventPatternParser:
     def __init__(self, pattern: Optional[str]):
         self.pattern = pattern
 
-    def _validate_event_pattern(self, pattern: Dict[str, Any]) -> None:
+    def _validate_event_pattern(self, pattern: dict[str, Any]) -> None:
         # values in the event pattern have to be either a dict or an array
         for attr, value in pattern.items():
             if isinstance(value, dict):
@@ -1038,9 +1149,9 @@ class EventPatternParser:
                     reason=f"'{attr}' must be an object or an array"
                 )
 
-    def parse(self) -> Dict[str, Any]:
+    def parse(self) -> dict[str, Any]:
         try:
-            parsed_pattern = json.loads(self.pattern) if self.pattern else dict()
+            parsed_pattern = json.loads(self.pattern) if self.pattern else {}
             self._validate_event_pattern(parsed_pattern)
             return parsed_pattern
         except JSONDecodeError:
@@ -1052,10 +1163,10 @@ class PartnerEventSource(BaseModel):
         self.name = name
         self.arn = f"arn:{get_partition(region)}:events:{region}::event-source/aws.partner/{name}"
         self.created_on = unix_time()
-        self.accounts: List[str] = []
+        self.accounts: list[str] = []
         self.state = "ACTIVE"
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "Arn": self.arn,
             "CreatedBy": self.name.split("/")[0],
@@ -1088,18 +1199,18 @@ class EventsBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.next_tokens: Dict[str, int] = {}
-        self.event_buses: Dict[str, EventBus] = {}
-        self.event_sources: Dict[str, PartnerEventSource] = {}
-        self.archives: Dict[str, Archive] = {}
-        self.replays: Dict[str, Replay] = {}
+        self.next_tokens: dict[str, int] = {}
+        self.event_buses: dict[str, EventBus] = {}
+        self.event_sources: dict[str, PartnerEventSource] = {}
+        self.archives: dict[str, Archive] = {}
+        self.replays: dict[str, Replay] = {}
         self.tagger = TaggingService()
 
         self._add_default_event_bus()
-        self.connections: Dict[str, Connection] = {}
-        self.destinations: Dict[str, Destination] = {}
-        self.partner_event_sources: Dict[str, PartnerEventSource] = {}
-        self.approved_parent_event_bus_names: List[str] = []
+        self.connections: dict[str, Connection] = {}
+        self.destinations: dict[str, Destination] = {}
+        self.partner_event_sources: dict[str, PartnerEventSource] = {}
+        self.approved_parent_event_bus_names: list[str] = []
 
     def _add_default_event_bus(self) -> None:
         self.event_buses["default"] = EventBus(
@@ -1134,7 +1245,7 @@ class EventsBackend(BaseBackend):
         scheduled_expression: Optional[str] = None,
         state: Optional[str] = None,
         managed_by: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
     ) -> Rule:
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
 
@@ -1158,7 +1269,7 @@ class EventsBackend(BaseBackend):
 
         event_bus = self._get_event_bus(event_bus_name)
         existing_rule = event_bus.rules.get(name)
-        targets = existing_rule.targets if existing_rule else list()
+        targets = existing_rule.targets if existing_rule else []
         rule = Rule(
             name,
             self.account_id,
@@ -1231,7 +1342,7 @@ class EventsBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_rule_names_by_target(
         self, target_arn: str, event_bus_arn: Optional[str]
-    ) -> List[Rule]:
+    ) -> list[Rule]:
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
         event_bus = self._get_event_bus(event_bus_name)
         matching_rules = []
@@ -1246,7 +1357,7 @@ class EventsBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_rules(
         self, prefix: Optional[str] = None, event_bus_arn: Optional[str] = None
-    ) -> List[Rule]:
+    ) -> list[Rule]:
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
         event_bus = self._get_event_bus(event_bus_name)
         match_string = ".*"
@@ -1266,7 +1377,7 @@ class EventsBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_targets_by_rule(  # type: ignore[misc]
         self, rule_id: str, event_bus_arn: Optional[str]
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         # We'll let a KeyError exception be thrown for response to handle if
         # rule doesn't exist.
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
@@ -1275,7 +1386,7 @@ class EventsBackend(BaseBackend):
         return rule.targets
 
     def put_targets(
-        self, name: str, event_bus_arn: Optional[str], targets: List[Dict[str, Any]]
+        self, name: str, event_bus_arn: Optional[str], targets: list[dict[str, Any]]
     ) -> None:
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
         event_bus = self._get_event_bus(event_bus_name)
@@ -1314,7 +1425,7 @@ class EventsBackend(BaseBackend):
 
         rule.put_targets(targets)
 
-    def put_events(self, events: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+    def put_events(self, events: list[dict[str, Any]]) -> list[dict[str, Any]]:
         """
         The following targets are supported at the moment:
 
@@ -1362,7 +1473,8 @@ class EventsBackend(BaseBackend):
                     detail = json.loads(event["Detail"])
                     if not isinstance(detail, dict):
                         warnings.warn(
-                            f"EventDetail should be of type dict - types such as {type(detail)} are ignored by AWS"
+                            f"EventDetail should be of type dict - types such as {type(detail)} are ignored by AWS",
+                            stacklevel=2,
                         )
                 except ValueError:  # json.JSONDecodeError exists since Python 3.5
                     entries.append(
@@ -1398,7 +1510,7 @@ class EventsBackend(BaseBackend):
         return entries
 
     def remove_targets(
-        self, name: str, event_bus_arn: Optional[str], ids: List[str]
+        self, name: str, event_bus_arn: Optional[str], ids: list[str]
     ) -> None:
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
         event_bus = self._get_event_bus(event_bus_name)
@@ -1426,8 +1538,8 @@ class EventsBackend(BaseBackend):
 
     @staticmethod
     def _condition_param_to_stmt_condition(  # type: ignore[misc]
-        condition: Optional[Dict[str, Any]],
-    ) -> Optional[Dict[str, Any]]:
+        condition: Optional[dict[str, Any]],
+    ) -> Optional[dict[str, Any]]:
         if condition:
             key = condition["Key"]
             value = condition["Value"]
@@ -1441,7 +1553,7 @@ class EventsBackend(BaseBackend):
         action: Optional[str],
         principal: str,
         statement_id: str,
-        condition: Dict[str, str],
+        condition: dict[str, str],
     ) -> None:
         if principal is None:
             raise JsonRESTError(
@@ -1484,7 +1596,7 @@ class EventsBackend(BaseBackend):
         action: str,
         principal: str,
         statement_id: str,
-        condition: Dict[str, str],
+        condition: dict[str, str],
         policy: str,
     ) -> None:
         if not event_bus_name:
@@ -1539,8 +1651,8 @@ class EventsBackend(BaseBackend):
         event_source_name: Optional[str] = None,
         description: Optional[str] = None,
         kms_key_identifier: Optional[str] = None,
-        dead_letter_config: Optional[Dict[str, str]] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        dead_letter_config: Optional[dict[str, str]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
     ) -> EventBus:
         if name in self.event_buses:
             raise JsonRESTError(
@@ -1573,7 +1685,7 @@ class EventsBackend(BaseBackend):
 
         return self.event_buses[name]
 
-    def list_event_buses(self, name_prefix: Optional[str]) -> List[EventBus]:
+    def list_event_buses(self, name_prefix: Optional[str]) -> list[EventBus]:
         if name_prefix:
             return [
                 event_bus
@@ -1592,7 +1704,7 @@ class EventsBackend(BaseBackend):
         if event_bus:
             self.tagger.delete_all_tags_for_resource(event_bus.arn)
 
-    def list_tags_for_resource(self, arn: str) -> Dict[str, List[Dict[str, str]]]:
+    def list_tags_for_resource(self, arn: str) -> dict[str, list[dict[str, str]]]:
         name = arn.split("/")[-1]
         rules = [bus.rules for bus in self.event_buses.values()]
         for registry in rules + [self.event_buses]:
@@ -1602,7 +1714,7 @@ class EventsBackend(BaseBackend):
             f"Rule {name} does not exist on EventBus default."
         )
 
-    def tag_resource(self, arn: str, tags: List[Dict[str, str]]) -> None:
+    def tag_resource(self, arn: str, tags: list[dict[str, str]]) -> None:
         name = arn.split("/")[-1]
         rules = [bus.rules for bus in self.event_buses.values()]
         for registry in rules + [self.event_buses]:
@@ -1613,7 +1725,7 @@ class EventsBackend(BaseBackend):
             f"Rule {name} does not exist on EventBus default."
         )
 
-    def untag_resource(self, arn: str, tag_names: List[str]) -> None:
+    def untag_resource(self, arn: str, tag_names: list[str]) -> None:
         name = arn.split("/")[-1]
         rules = [bus.rules for bus in self.event_buses.values()]
         for registry in rules + [self.event_buses]:
@@ -1685,7 +1797,7 @@ class EventsBackend(BaseBackend):
 
         return archive
 
-    def describe_archive(self, name: str) -> Dict[str, Any]:
+    def describe_archive(self, name: str) -> dict[str, Any]:
         archive = self.archives.get(name)
 
         if not archive:
@@ -1698,7 +1810,7 @@ class EventsBackend(BaseBackend):
         name_prefix: Optional[str],
         source_arn: Optional[str],
         state: Optional[str],
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         if [name_prefix, source_arn, state].count(None) < 2:
             raise ValidationException(
                 "At most one filter is allowed for ListArchives. "
@@ -1730,7 +1842,7 @@ class EventsBackend(BaseBackend):
 
     def update_archive(
         self, name: str, description: str, event_pattern: str, retention: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         archive = self.archives.get(name)
 
         if not archive:
@@ -1759,8 +1871,8 @@ class EventsBackend(BaseBackend):
         source_arn: str,
         start_time: str,
         end_time: str,
-        destination: Dict[str, Any],
-    ) -> Dict[str, Any]:
+        destination: dict[str, Any],
+    ) -> dict[str, Any]:
         event_bus_arn = destination["Arn"]
         event_bus_arn_pattern = (
             rf"{ARN_PARTITION_REGEX}:events:[a-zA-Z0-9-]+:\d{{12}}:event-bus/"
@@ -1815,14 +1927,14 @@ class EventsBackend(BaseBackend):
             "State": ReplayState.STARTING.value,  # the replay will be done before returning the response
         }
 
-    def describe_replay(self, name: str) -> Dict[str, Any]:
+    def describe_replay(self, name: str) -> dict[str, Any]:
         replay = self._get_replay(name)
 
         return replay.describe()
 
     def list_replays(
         self, name_prefix: str, source_arn: str, state: str
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         if [name_prefix, source_arn, state].count(None) < 2:  # type: ignore
             raise ValidationException(
                 "At most one filter is allowed for ListReplays. "
@@ -1851,7 +1963,7 @@ class EventsBackend(BaseBackend):
 
         return result
 
-    def cancel_replay(self, name: str) -> Dict[str, str]:
+    def cancel_replay(self, name: str) -> dict[str, str]:
         replay = self._get_replay(name)
 
         # replays in the state 'COMPLETED' can't be canceled,
@@ -1875,7 +1987,7 @@ class EventsBackend(BaseBackend):
         name: str,
         description: str,
         authorization_type: str,
-        auth_parameters: Dict[str, Any],
+        auth_parameters: dict[str, Any],
     ) -> Connection:
         connection = Connection(
             name,
@@ -1888,7 +2000,7 @@ class EventsBackend(BaseBackend):
         self.connections[name] = connection
         return connection
 
-    def update_connection(self, name: str, **kwargs: Any) -> Dict[str, Any]:
+    def update_connection(self, name: str, **kwargs: Any) -> dict[str, Any]:
         connection = self.connections.get(name)
         if not connection:
             raise ResourceNotFoundException(f"Connection '{name}' does not exist.")
@@ -1898,17 +2010,17 @@ class EventsBackend(BaseBackend):
                 setattr(connection, attr, value)
         return connection.describe_short()
 
-    def list_connections(self) -> List[Connection]:
+    def list_connections(self) -> list[Connection]:
         return list(self.connections.values())
 
-    def describe_connection(self, name: str) -> Dict[str, Any]:
+    def describe_connection(self, name: str) -> dict[str, Any]:
         connection = self.connections.get(name)
         if not connection:
             raise ResourceNotFoundException(f"Connection '{name}' does not exist.")
 
         return connection.describe()
 
-    def delete_connection(self, name: str) -> Dict[str, Any]:
+    def delete_connection(self, name: str) -> dict[str, Any]:
         connection = self.connections.pop(name, None)
         if not connection:
             raise ResourceNotFoundException(f"Connection '{name}' does not exist.")
@@ -1933,7 +2045,7 @@ class EventsBackend(BaseBackend):
         invocation_endpoint: str,
         invocation_rate_limit_per_second: str,
         http_method: str,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         destination = Destination(
             name=name,
             account_id=self.account_id,
@@ -1948,10 +2060,10 @@ class EventsBackend(BaseBackend):
         self.destinations[name] = destination
         return destination.describe_short()
 
-    def list_api_destinations(self) -> List[Destination]:
+    def list_api_destinations(self) -> list[Destination]:
         return list(self.destinations.values())
 
-    def describe_api_destination(self, name: str) -> Dict[str, Any]:
+    def describe_api_destination(self, name: str) -> dict[str, Any]:
         destination = self.destinations.get(name)
         if not destination:
             raise ResourceNotFoundException(
@@ -1959,7 +2071,7 @@ class EventsBackend(BaseBackend):
             )
         return destination.describe()
 
-    def update_api_destination(self, name: str, **kwargs: Any) -> Dict[str, Any]:
+    def update_api_destination(self, name: str, **kwargs: Any) -> dict[str, Any]:
         destination = self.destinations.get(name)
         if not destination:
             raise ResourceNotFoundException(
@@ -1998,7 +2110,7 @@ class EventsBackend(BaseBackend):
         client_backend = events_backends[account_id][self.region_name]
         client_backend.event_sources[name].state = "DELETED"
 
-    def put_partner_events(self, entries: List[Dict[str, Any]]) -> None:
+    def put_partner_events(self, entries: list[dict[str, Any]]) -> None:
         """
         Validation of the entries is not yet implemented.
         """
