@@ -1,28 +1,30 @@
-from abc import abstractmethod, ABCMeta
-from collections import namedtuple
-from typing import Any, Dict, Tuple, List
-from enum import Enum
+import base64
+import hashlib
+import hmac
 import io
 import os
 import struct
-from moto.moto_api._internal import mock_random
+from abc import ABCMeta, abstractmethod
+from collections import namedtuple
+from enum import Enum
+from typing import Any
 
 from cryptography.exceptions import InvalidSignature
 from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives.ciphers import algorithms, Cipher, modes
 from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives._asymmetric import AsymmetricPadding
-from cryptography.hazmat.primitives.asymmetric import rsa, padding, ec
+from cryptography.hazmat.primitives.asymmetric import ec, padding, rsa
+from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
 
+from moto.moto_api._internal import mock_random
 
 from .exceptions import (
-    InvalidCiphertextException,
     AccessDeniedException,
+    InvalidCiphertextException,
     NotFoundException,
     ValidationException,
 )
 
-
 MASTER_KEY_LEN = 32
 KEY_ID_LEN = 36
 IV_LEN = 12
@@ -72,19 +74,19 @@ class KeySpec(str, Enum):
     HMAC_512 = "HMAC_512"
 
     @classmethod
-    def key_specs(self) -> List[str]:
+    def key_specs(self) -> list[str]:
         return sorted([item.value for item in KeySpec])
 
     @classmethod
-    def rsa_key_specs(self) -> List[str]:
+    def rsa_key_specs(self) -> list[str]:
         return [spec for spec in self.key_specs() if spec.startswith("RSA")]
 
     @classmethod
-    def ecc_key_specs(self) -> List[str]:
+    def ecc_key_specs(self) -> list[str]:
         return [spec for spec in self.key_specs() if spec.startswith("ECC")]
 
     @classmethod
-    def hmac_key_specs(self) -> List[str]:
+    def hmac_key_specs(self) -> list[str]:
         return [spec for spec in self.key_specs() if spec.startswith("HMAC")]
 
 
@@ -106,15 +108,15 @@ class SigningAlgorithm(str, Enum):
     SM2DSA = "SM2DSA"
 
     @classmethod
-    def signing_algorithms(self) -> List[str]:
+    def signing_algorithms(self) -> list[str]:
         return sorted([item.value for item in SigningAlgorithm])
 
     @classmethod
-    def rsa_signing_algorithms(self) -> List[str]:
+    def rsa_signing_algorithms(self) -> list[str]:
         return [algo for algo in self.signing_algorithms() if algo.startswith("RSASSA")]
 
     @classmethod
-    def ecc_signing_algorithms(self) -> List[str]:
+    def ecc_signing_algorithms(self) -> list[str]:
         return [algo for algo in self.signing_algorithms() if algo.startswith("ECDSA")]
 
 
@@ -154,24 +156,20 @@ class AbstractPrivateKey(metaclass=ABCMeta):
 
 
 def validate_signing_algorithm(
-    target_algorithm: str, valid_algorithms: List[str]
+    target_algorithm: str, valid_algorithms: list[str]
 ) -> None:
     if target_algorithm not in valid_algorithms:
         raise ValidationException(
-            (
-                "1 validation error detected: Value at 'signing_algorithm' failed"
-                "to satisfy constraint: Member must satisfy enum value set: {valid_signing_algorithms}"
-            ).format(valid_signing_algorithms=valid_algorithms)
+            "1 validation error detected: Value at 'signing_algorithm' failed"
+            f"to satisfy constraint: Member must satisfy enum value set: {valid_algorithms}"
         )
 
 
-def validate_key_spec(target_key_spec: str, valid_key_specs: List[str]) -> None:
+def validate_key_spec(target_key_spec: str, valid_key_specs: list[str]) -> None:
     if target_key_spec not in valid_key_specs:
         raise ValidationException(
-            (
-                "1 validation error detected: Value at 'key_spec' failed "
-                "to satisfy constraint: Member must satisfy enum value set: {valid_key_specs}"
-            ).format(valid_key_specs=valid_key_specs)
+            "1 validation error detected: Value at 'key_spec' failed "
+            f"to satisfy constraint: Member must satisfy enum value set: {valid_key_specs}"
         )
 
 
@@ -182,10 +180,8 @@ class RSAPrivateKey(AbstractPrivateKey):
     def __init__(self, key_size: int):
         if key_size not in self.__supported_key_sizes:
             raise ValidationException(
-                (
-                    "1 validation error detected: Value at 'key_size' failed "
-                    "to satisfy constraint: Member must satisfy enum value set: {supported_key_sizes}"
-                ).format(supported_key_sizes=self.__supported_key_sizes)
+                "1 validation error detected: Value at 'key_size' failed "
+                f"to satisfy constraint: Member must satisfy enum value set: {self.__supported_key_sizes}"
             )
         self.key_size = key_size
         self.private_key = rsa.generate_private_key(
@@ -194,7 +190,7 @@ class RSAPrivateKey(AbstractPrivateKey):
 
     def __padding_and_hash_algorithm(
         self, signing_algorithm: str
-    ) -> Tuple[AsymmetricPadding, hashes.HashAlgorithm]:
+    ) -> tuple[AsymmetricPadding, hashes.HashAlgorithm]:
         if signing_algorithm == SigningAlgorithm.RSASSA_PSS_SHA_256:
             pad = padding.PSS(
                 mgf=padding.MGF1(hashes.SHA256()), salt_length=padding.PSS.MAX_LENGTH
@@ -253,7 +249,7 @@ class ECDSAPrivateKey(AbstractPrivateKey):
 
         if key_spec == KeySpec.ECC_NIST_P256:
             curve = ec.SECP256R1()  # type: ec.EllipticCurve
-            valid_signing_algorithms = ["ECDSA_SHA_256"]  # type: List[str]
+            valid_signing_algorithms = ["ECDSA_SHA_256"]
         elif key_spec == KeySpec.ECC_SECG_P256K1:
             curve = ec.SECP256K1()
             valid_signing_algorithms = ["ECDSA_SHA_256"]
@@ -339,7 +335,7 @@ def _deserialize_ciphertext_blob(ciphertext_blob: bytes) -> Ciphertext:
     )
 
 
-def _serialize_encryption_context(encryption_context: Dict[str, str]) -> bytes:
+def _serialize_encryption_context(encryption_context: dict[str, str]) -> bytes:
     """Serialize encryption context for use a AAD.
 
     NOTE: This is not necessarily what KMS does, but it retains the same properties.
@@ -352,10 +348,10 @@ def _serialize_encryption_context(encryption_context: Dict[str, str]) -> bytes:
 
 
 def encrypt(
-    master_keys: Dict[str, Any],
+    master_keys: dict[str, Any],
     key_id: str,
     plaintext: bytes,
-    encryption_context: Dict[str, str],
+    encryption_context: dict[str, str],
 ) -> bytes:
     """Encrypt data using a master key material.
 
@@ -380,6 +376,10 @@ def encrypt(
         raise ValidationException(
             "1 validation error detected: Value at 'plaintext' failed to satisfy constraint: Member must have length greater than or equal to 1"
         )
+    if len(plaintext) > 4096:
+        raise ValidationException(
+            "1 validation error detected: Value at 'plaintext' failed to satisfy constraint: Member must have length less than or equal to 4096"
+        )
 
     iv = os.urandom(IV_LEN)
     aad = _serialize_encryption_context(encryption_context=encryption_context)
@@ -397,10 +397,10 @@ def encrypt(
 
 
 def decrypt(
-    master_keys: Dict[str, Any],
+    master_keys: dict[str, Any],
     ciphertext_blob: bytes,
-    encryption_context: Dict[str, str],
-) -> Tuple[bytes, str]:
+    encryption_context: dict[str, str],
+) -> tuple[bytes, str]:
     """Decrypt a ciphertext blob using a master key material.
 
     NOTE: This is not necessarily what KMS does, but it retains the same properties.
@@ -440,3 +440,28 @@ def decrypt(
         raise InvalidCiphertextException()
 
     return plaintext, ciphertext.key_id
+
+
+def generate_hmac(
+    key: bytes,
+    message: bytes,
+    mac_algorithm: str,
+) -> str:
+    """
+    Returns a base64 encoded HMAC
+    """
+
+    algos = {
+        "HMAC_SHA_224": hashlib.sha224,
+        "HMAC_SHA_256": hashlib.sha256,
+        "HMAC_SHA_384": hashlib.sha384,
+        "HMAC_SHA_512": hashlib.sha512,
+    }
+
+    hmac_val = hmac.new(
+        key=key,
+        msg=message,
+        digestmod=algos[mac_algorithm],
+    )
+
+    return base64.b64encode(hmac_val.digest()).decode("utf-8")
