@@ -1,8 +1,8 @@
-from typing import Final, List
+from typing import Final
 
 from moto.stepfunctions.parser.asl.component.intrinsic.component import Component
 
 
 class Program(Component):
     def __init__(self):
-        self.statements: Final[List[Component]] = []
+        self.statements: Final[list[Component]] = []
