@@ -17,4 +17,6 @@ url_paths = {
     "{0}/services/(?P<serviceIdentifier>.+)$": VPCLatticeResponse.dispatch,
     "{0}/servicenetworks/(?P<serviceNetworkIdentifier>.+)$": VPCLatticeResponse.dispatch,
     "{0}/tags/(?P<resourceArn>[^/]+)?tagKeys=(?P<tagKeys>[^/]+)$": VPCLatticeResponse.dispatch,
+    "{0}/resourcepolicy/(?P<resourceIdentifier>.+)$": VPCLatticeResponse.dispatch,
+    "{0}/authpolicy/(?P<resourceIdentifier>.+)$": VPCLatticeResponse.dispatch,
 }
